female_prefix = [
    "ana",
    "ara",
    "bel",
    "dara",
    "elena",
    "ira",
    "kata",
    "lena",
    "mara",
    "nina",
    "oksana",
    "pela",
    "rada",
    "sara",
    "tana",
    "ula",
    "vala",
    "wera",
    "xena",
    "yara",
    "zara",
    "ada",
    "bela",
    "gala",
    "jana",
    "kira",
    "lana",
    "mila",
    "nata",
    "ola",
]

female_suffix = [
    "ala",
    "ara",
    "ela",
    "ina",
    "ira",
    "lina",
    "mila",
    "naya",
    "nya",
    "sana",
    "tina",
    "ya",
    "yana",
    "yara",
    "yla",
    "yra",
    "asha",
    "enka",
    "iska",
    "kina",
    "lena",
    "mira",
    "nika",
    "rina",
    "sya",
    "tina",
    "usha",
    "vina",
    "ysha",
    "za",
]

male_prefix = [
    "aleks",
    "and",
    "art",
    "bor",
    "den",
    "dmitr",
    "evgen",
    "fel",
    "genn",
    "grig",
    "ily",
    "ivan",
    "kir",
    "kon",
    "leon",
    "maks",
    "mikh",
    "nik",
    "oleg",
    "pavel",
    "petr",
    "roman",
    "serg",
    "stan",
    "tim",
    "vadim",
    "valer",
    "vict",
    "vlad",
    "yur",
]

male_suffix = [
    "an",
    "ar",
    "ev",
    "i",
    "ian",
    "in",
    "is",
    "iy",
    "k",
    "ko",
    "mi",
    "nic",
    "o",
    "omir",
    "or",
    "ov",
    "ri",
    "ski",
    "slav",
    "slov",
    "tar",
    "ti",
    "ton",
    "v",
    "vi",
    "vol",
    "y",
    "yev",
    "yin",
    "yush",
]

surname_prefix = [
    "ale",
    "an",
    "bor",
    "che",
    "dmi",
    "ef",
    "gav",
    "igor",
    "kap",
    "lar",
    "mikh",
    "nik",
    "ole",
    "pav",
    "rog",
    "serg",
    "tar",
    "vlad",
    "yev",
    "zhen",
    "zol",
    "ish",
    "kaz",
    "lev",
    "maks",
    "nov",
    "oleg",
    "pyot",
    "rud",
    "sash",
]

surname_suffix = [
    "ev",
    "in",
    "ov",
    "ski",
    "sky",
    "ko",
    "ov",
    "evich",
    "ovich",
    "yev",
    "yevich",
    "enko",
    "chuk",
    "ikh",
    "enko",
    "shin",
    "ayev",
    "nov",
    "yuk",
    "ukov",
    "yakin",
    "tsov",
    "kin",
    "kov",
    "nyuk",
    "tsy",
]

female_names = [
    "Ada",
    "Adałajda",
    "Adela",
    "Adelajda",
    "Adrianna",
    "Agata",
    "Agnieszka",
    "Agrypina",
    "Aldona",
    "Aleksandra",
    "Alena",
    "Alicja",
    "Amelia",
    "Anastazja",
    "Aniela",
    "Anna",
    "Antonina",
    "Apolonia",
    "Aurelia",
    "Barbara",
    "Bartłomieja",
    "Bazylika",
    "Berta",
    "Bianka",
    "Bogdana",
    "Bogna",
    "Bolesława",
    "Bożena",
    "Bronisława",
    "Cecylia",
    "Cecylka",
    "Cezaria",
    "Czesława",
    "Czyża",
    "Dagmara",
    "Dagmary",
    "Dalia",
    "Daniela",
    "Danuta",
    "Debora",
    "Diana",
    "Dobrawa",
    "Domicela",
    "Donata",
    "Dorota",
    "Dorotka",
    "Dusza",
    "Edmunda",
    "Edyta",
    "Edytki",
    "Ela",
    "Eleonora",
    "Eliza",
    "Elżbieta",
    "Emilia",
    "Emilka",
    "Emmy",
    "Estera",
    "Eugenia",
    "Ewa",
    "Ewelina",
    "Ezabella",
    "Felicja",
    "Franciszka",
    "Gabriela",
    "Gabriella",
    "Genowefa",
    "Gertruda",
    "Gisela",
    "Gizela",
    "Gloria",
    "Grażyna",
    "Halina",
    "Halinka",
    "Hanna",
    "Helena",
    "Helenka",
    "Helga",
    "Henrieta",
    "Honorata",
    "Ida",
    "Idalia",
    "Idzia",
    "Iga",
    "Ignacja",
    "Ika",
    "Ilona",
    "Inga",
    "Inka",
    "Innocenta",
    "Irena",
    "Irmina",
    "Iwa",
    "Iwona",
    "Iza",
    "Izabella",
    "Izolda",
    "Jadwiga",
    "Jaga",
    "Jagna",
    "Jagoda",
    "Janina",
    "Jarmiła",
    "Jasmina",
    "Jasna",
    "Joanna",
    "Jolanta",
    "Jolka",
    "Jowina",
    "Jowita",
    "Judyta",
    "Julia",
    "Julitta",
    "Julka",
    "Justa",
    "Justyna",
    "Juta",
    "Kalina",
    "Kamila",
    "Kanty",
    "Karina",
    "Karolina",
    "Kasandra",
    "Katarzyna",
    "Katarzynka",
    "Kazimiera",
    "Kinga",
    "Klaudia",
    "Klementyna",
    "Kleopatra",
    "Kordelia",
    "Kornelia",
    "Kosma",
    "Krysta",
    "Krystyna",
    "Krystynka",
    "Krzysztofa",
    "Ksawera",
    "Lidia",
    "Lidka",
    "Lili",
    "Liliana",
    "Liza",
    "Lora",
    "Ludmila",
    "Ludmiła",
    "Luiza",
    "Magda",
    "Magdalena",
    "Maja",
    "Malina",
    "Mandolina",
    "Marcelina",
    "Margarita",
    "Maria",
    "Mariam",
    "Marianna",
    "Marietta",
    "Marta",
    "Martka",
    "Martyna",
    "Marzanna",
    "Matylda",
    "Małgorzata",
    "Melania",
    "Milena",
    "Mira",
    "Mirella",
    "Mirka",
    "Mirosława",
    "Miła",
    "Monika",
    "Nadia",
    "Natalia",
    "Nikola",
    "Nikolina",
    "Nina",
    "Nora",
    "Oda",
    "Ola",
    "Olga",
    "Olimpia",
    "Olina",
    "Oliwia",
    "Olka",
    "Otylia",
    "Patrycja",
    "Paula",
    "Paulina",
    "Pelagia",
    "Pola",
    "Rachela",
    "Regina",
    "Renata",
    "Rita",
    "Roksana",
    "Roksanka",
    "Rozalia",
    "Rozalinda",
    "Róża",
    "Saba",
    "Sabina",
    "Sandra",
    "Sara",
    "Sebastiana",
    "Serafina",
    "Serapia",
    "Seweryna",
    "Sibilla",
    "Sonia",
    "Sophia",
    "Stanisława",
    "Stefania",
    "Stela",
    "Swietłana",
    "Sylwana",
    "Sylwia",
    "Taida",
    "Tamara",
    "Tatiana",
    "Teresa",
    "Tola",
    "Tosia",
    "Ula",
    "Urszula",
    "Walentyna",
    "Waleria",
    "Wanda",
    "Weronika",
    "Wiktoria",
    "Wilhelmina",
    "Wioleta",
    "Zdzisława",
    "Zenobia",
    "Zina",
    "Zofia",
    "Zuzanna",
]

male_names = [
    "Agaton",
    "Aleksandr",
    "Anatol",
    "Anatoli",
    "Andrei",
    "Anton",
    "Arkadi",
    "Arsen",
    "Bartolomej",
    "Benedikt",
    "Bogdan",
    "Bogomir",
    "Bogumil",
    "Boguslav",
    "Boleslav",
    "Boris",
    "Borislav",
    "Bozhidar",
    "Branimir",
    "Branislav",
    "Cyril",
    "Danko",
    "Dimitar",
    "Dimitri",
    "Dobromil",
    "Dobromir",
    "Dobroslav",
    "Dominik",
    "Dragan",
    "Dragomir",
    "Drazhan",
    "Dusan",
    "Edmund",
    "Eduard",
    "Emil",
    "Emilian",
    "Erazim",
    "Evdokim",
    "Evgeni",
    "Fedor",
    "Feofil",
    "Gavril",
    "Gedeon",
    "Georgi",
    "Gleb",
    "Goran",
    "Gregor",
    "Grigori",
    "Gustav",
    "Hristo",
    "Igor",
    "Ilia",
    "Iliya",
    "Ilyas",
    "Ivan",
    "Janko",
    "Jaromir",
    "Kamen",
    "Kazimir",
    "Kiril",
    "Konstantin",
    "Kostadin",
    "Kostya",
    "Kuzma",
    "Ladislav",
    "Lazar",
    "Leonid",
    "Lev",
    "Lubomir",
    "Lyubomir",
    "Maksim",
    "Marko",
    "Matej",
    "Matvey",
    "Mihail",
    "Mikhail",
    "Milan",
    "Miroslav",
    "Nestor",
    "Nikola",
    "Nikolai",
    "Nikolay",
    "Oleg",
    "Orest",
    "Panteley",
    "Pavel",
    "Petar",
    "Piotr",
    "Radimir",
    "Radomir",
    "Radoslav",
    "Radovan",
    "Rastislav",
    "Ratimir",
    "Ratko",
    "Robert",
    "Rodion",
    "Rodomil",
    "Rodoslav",
    "Roman",
    "Rostislav",
    "Ruslan",
    "Sasha",
    "Sava",
    "Saveliy",
    "Sergei",
    "Sergey",
    "Sokrat",
    "Stanimir",
    "Stanislav",
    "Stefan",
    "Svetoslav",
    "Svyatoslav",
    "Tadej",
    "Tihomir",
    "Timofei",
    "Timur",
    "Todor",
    "Valdemar",
    "Valentin",
    "Valeri",
    "Vasil",
    "Velimir",
    "Viktor",
    "Vladimir",
    "Vladislav",
    "Vlastimir",
    "Volodya",
    "Vsevolod",
    "Vukan",
    "Yakov",
    "Yan",
    "Yaromir",
    "Yaroslav",
    "Yasen",
    "Yulian",
    "Yuri",
    "Zahar",
    "Zbignev",
    "Zdravko",
    "Zhdan",
    "Zinoviy",
    "Zlatan",
    "Zlatko",
    "Zlatomir",
    "Zoran",
    "Zosim",
    "Zvenimir",
    "Zvonimir",
    "Zvonko",
    "Zygmunt",
]

surnames = [
    "Abramović",
    "Agapov",
    "Aleksandrov",
    "Alekseev",
    "Anastasov",
    "Andreev",
    "Anděl",
    "Antonović",
    "Babić",
    "Bogdanov",
    "Borisov",
    "Bosnić",
    "Bozhkov",
    "Bílý",
    "Cibulka",
    "Cvetković",
    "Denisov",
    "Dimitrov",
    "Dmitriev",
    "Dobrev",
    "Dobrovolny",
    "Dvořák",
    "Elias",
    "Emilov",
    "Evgeniev",
    "Evseev",
    "Fedorov",
    "Filipović",
    "Filippov",
    "Ganchev",
    "Gavrilov",
    "Gennadiev",
    "Georgiev",
    "Grigoriev",
    "Grujić",
    "Horák",
    "Hristov",
    "Hájek",
    "Ignatov",
    "Iliev",
    "Ilić",
    "Ilyin",
    "Ivanov",
    "Ivanović",
    "Janković",
    "Jirásek",
    "Jordanov",
    "Jovanović",
    "Kirillov",
    "Kirilov",
    "Kostov",
    "Kovačević",
    "Kováč",
    "Kozák",
    "Kuznetsov",
    "Lazarević",
    "Lazarov",
    "Lebedev",
    "Leonidov",
    "Luchev",
    "Lukić",
    "Maksimov",
    "Marek",
    "Marinov",
    "Marković",
    "Mihaylov",
    "Mikhailov",
    "Mládek",
    "Nikolaev",
    "Nikolayev",
    "Nikolić",
    "Nikolov",
    "Novák",
    "Němec",
    "Obradović",
    "Olegov",
    "Olegovich",
    "Olšák",
    "Pavlov",
    "Pavlović",
    "Pavlíček",
    "Petkov",
    "Petrov",
    "Petrović",
    "Radkov",
    "Radojičić",
    "Radoslavov",
    "Romanov",
    "Rostislavov",
    "Russo",
    "Růžička",
    "Sergeev",
    "Sergeyev",
    "Simeonov",
    "Sokolov",
    "Stefanov",
    "Stojanović",
    "Timofeev",
    "Todorov",
    "Tomić",
    "Tomášek",
    "Tůma",
    "Uhlíř",
    "Valentinov",
    "Vasiliev",
    "Vasiljević",
    "Veselý",
    "Viktorov",
    "Vladimirov",
    "Vlček",
    "Yakovlev",
    "Yordanov",
    "Yuryev",
    "Zahariev",
    "Zaharov",
    "Zahradník",
    "Zakharov",
    "Zima",
    "Černý",
    "Đorđević",
    "Ševčík",
]



female_prefix = [
    "aða",
    "æl",
    "arn",
    "björn",
    "dís",
    "eið",
    "ey",
    "fríð",
    "gud",
    "gull",
    "gyð",
    "hild",
    "hjör",
    "ing",
    "líf",
    "run",
    "sif",
    "skjald",
    "skuld",
    "sól",
    "thor",
    "val",
    "víg",
    "ygg",
]

female_suffix = [
    "björg",
    "dóttir",
    "ey",
    "fey",
    "fríða",
    "gärd",
    "gyða",
    "hild",
    "hjör",
    "inga",
    "lína",
    "runa",
    "sigríð",
    "skjöld",
    "skuld",
    "sól",
    "thor",
    "vald",
    "ví",
    "vig",
    "ygg",
]

male_prefix = [
    "að",
    "al",
    "arn",
    "ask",
    "bað",
    "bjǫrn",
    "dǫrr",
    "eir",
    "ein",
    "fjǫr",
    "geir",
    "grim",
    "gunn",
    "hǫrð",
    "ing",
    "jarl",
    "kárr",
    "kol",
    "leifr",
    "mǫrk",
    "njal",
    "od",
    "ǫrn",
    "rauð",
    "skǫgr",
    "steinn",
    "tórr",
    "úlfr",
    "vald",
    "víð",
    "yng",
]

male_suffix = [
    "arr",
    "bjǫrn",
    "dall",
    "einarr",
    "fang",
    "geir",
    "grimr",
    "hǫrðr",
    "iarr",
    "jǫrn",
    "kell",
    "lárr",
    "mann",
    "njarð",
    "olfr",
    "ráð",
    "skell",
    "steinn",
    "thórr",
    "ulf",
    "valdr",
    "víðr",
    "yrn",
]

surname_prefix = [
    "aeg",
    "aer",
    "arn",
    "as",
    "baer",
    "ber",
    "bjorn",
    "daeg",
    "dagr",
    "ein",
    "eir",
    "ey",
    "freyr",
    "gar",
    "geir",
    "grim",
    "haeg",
    "haer",
    "haf",
    "hald",
    "har",
    "hjor",
    "kjaer",
    "leifr",
    "mund",
    "raed",
    "raeg",
    "ran",
    "saer",
    "sig",
    "skjold",
    "staf",
    "stein",
    "svein",
    "thaeg",
    "thor",
    "tor",
    "ulfr",
    "vaeg",
    "vaer",
    "vald",
    "veig",
    "ver",
    "vid",
    "vigr",
    "vind",
    "yng",
]

surname_suffix = [
    "ard",
    "bjorn",
    "brand",
    "dal",
    "dottir",
    "drifa",
    "drot",
    "eidr",
    "fast",
    "fjord",
    "flod",
    "frej",
    "gard",
    "gils",
    "haugr",
    "heim",
    "hildr",
    "holt",
    "ing",
    "jord",
    "kjold",
    "lind",
    "magn",
    "nord",
    "rafn",
    "rak",
    "rik",
    "sif",
    "skar",
    "son",
    "stein",
    "stir",
    "thor",
    "tor",
    "ulf",
    "vald",
    "vang",
    "ve",
    "vig",
    "vin",
    "vir",
    "vor",
    "yng",
    "yv",
]

female_names = [
    "Aesa",
    "Alfhildr",
    "Alruna",
    "Astridr",
    "Audhildr",
    "Bera",
    "Bergljot",
    "Bodil",
    "Brynhildr",
    "Dagny",
    "Eir",
    "Eiriksdottir",
    "Estrid",
    "Eydis",
    "Frida",
    "Gerda",
    "Gudrun",
    "Gunnhildr",
    "Gyda",
    "Hedvig",
    "Helga",
    "Herdis",
    "Hilde",
    "Hildr",
    "Idunn",
    "Ingeborg",
    "Ingrid",
    "Jofrid",
    "Kara",
    "Kari",
    "Kirsten",
    "Liv",
    "Maren",
    "Ragna",
    "Ragnhildr",
    "Ranveig",
    "Runa",
    "Saga",
    "Sif",
    "Signy",
    "Sigrid",
    "Sigrun",
    "Skadi",
    "Solveig",
    "Stikla",
    "Svanhildr",
    "Thora",
    "Thyra",
    "Torhildr",
    "Tove",
    "Unn",
    "Vigdis",
    "Yngvildr",
    "Yrsa",
]

male_names = [
    "Agnar",
    "Alfr",
    "Alof",
    "Ansgar",
    "Arnbjorn",
    "Arnbjörn",
    "Arngeir",
    "Arvid",
    "Asgeir",
    "Baldur",
    "Bard",
    "Bengt",
    "Birger",
    "Bjorn",
    "Björn",
    "Dag",
    "Dagfinn",
    "Dagfinnr",
    "Egil",
    "Einar",
    "Eindride",
    "Eirikr",
    "Erik",
    "Erling",
    "Eskil",
    "Finn",
    "Finnr",
    "Folke",
    "Frej",
    "Freyr",
    "Frode",
    "Geir",
    "Geirr",
    "Gormr",
    "Grím",
    "Gudmundr",
    "Gunnar",
    "Gunnbjorn",
    "Gustav",
    "Gyril",
    "Gísli",
    "Hakon",
    "Halfdan",
    "Halfdanr",
    "Halldór",
    "Hallvarðr",
    "Halvar",
    "Halvdan",
    "Harald",
    "Hartvig",
    "Hauk",
    "Haukr",
    "Heimdalr",
    "Helgi",
    "Hemming",
    "Hjalmar",
    "Hjálmar",
    "Höskuld",
    "Ingemar",
    "Ivar",
    "Jarl",
    "Jofrid",
    "Johan",
    "Jorund",
    "Jóhann",
    "Ketil",
    "Ketill",
    "Knut",
    "Konráð",
    "Kári",
    "Lasse",
    "Leif",
    "Leifr",
    "Ljót",
    "Magne",
    "Magnus",
    "Magnús",
    "Njord",
    "Njål",
    "Odd",
    "Oddgeir",
    "Oddr",
    "Ogmund",
    "Olaf",
    "Ormr",
    "Orvar",
    "Peder",
    "Ragnar",
    "Ragnarr",
    "Rane",
    "Rasmus",
    "Rolf",
    "Rögnir",
    "Rúni",
    "Sigbjorn",
    "Sigmundr",
    "Sigurd",
    "Sindri",
    "Stefan",
    "Steinar",
    "Styrbjörn",
    "Svante",
    "Sven",
    "Svend",
    "Teitur",
    "Teodor",
    "Thorbjorn",
    "Thore",
    "Thorfinn",
    "Torfi",
    "Torkel",
    "Torsten",
    "Tryggvi",
    "Tómas",
    "Ulf",
    "Ulrik",
    "Valdimarr",
    "Valr",
    "Verner",
    "Vidar",
    "Viggo",
    "Viglaf",
    "Vésteinn",
    "Víga-Hrappr",
    "Víkingr",
    "Yngvar",
    "Yngvarr",
    "Yngve",
    "Ärnljot",
    "Åke",
    "Åsgeir",
    "Åsleif",
    "Ívarr",
    "Óðinn",
    "Örjan",
    "Úlfr",
    "Þorfinnr",
    "Þorgrímr",
    "Þorsteinn",
    "Þrymr",
    "Þrándr",
    "Þrœndr",
    "Þórgeirr",
    "Þórketill",
    "Þórsteinn",
    "Þórvaldr",
    "Þórðr",
]

surnames = [
    "Aesirsson",
    "Agni",
    "Alderson",
    "Arnesson",
    "Arngrim",
    "Asgeir",
    "Asgeirsson",
    "Askell",
    "Askellson",
    "Baldr",
    "Baldrsson",
    "Bjorn",
    "Bjornsson",
    "Egil",
    "Egilsson",
    "Einar",
    "Einarsdottir",
    "Eirik",
    "Eiriksson",
    "Finn",
    "Finnsson",
    "Fjeldsted",
    "Freyrsson",
    "Frostisson",
    "Gudmund",
    "Gudmundsson",
    "Gunnar",
    "Gunnarsson",
    "Halfdan",
    "Halfdansson",
    "Halvar",
    "Halvarsson",
    "Harald",
    "Haraldsson",
    "Havard",
    "Havardsson",
    "Helgason",
    "Helgi",
    "Herjolf",
    "Herjolfsson",
    "Hjalmarr",
    "Hjalmarsdottir",
    "Holger",
    "Holgersson",
    "Hrolf",
    "Hrolfsson",
    "Ingebrigtsdottir",
    "Ivar",
    "Ivarsson",
    "Jarl",
    "Jarlsson",
    "Jokul",
    "Jokulsson",
    "Ketil",
    "Ketilsson",
    "Kolbein",
    "Kolbeinsson",
    "Leif",
    "Leifsdottir",
    "Loki",
    "Lokisson",
    "Magnus",
    "Magnusson",
    "Njord",
    "Njordsson",
    "Odin",
    "Odinson",
    "Olaf",
    "Olafsdottir",
    "Olavsson",
    "Oskar",
    "Oskarsson",
    "Ragnar",
    "Ragnarsson",
    "Rolf",
    "Rolfsson",
    "Sigmund",
    "Sigmundsson",
    "Sigurd",
    "Sigurdsson",
    "Sjurs",
    "Sjursdottir",
    "Skarphedin",
    "Skarphedinsson",
    "Skjold",
    "Skjoldsson",
    "Snorresson",
    "Snorri",
    "Sven",
    "Svennson",
    "Thorbjorn",
    "Thorbjornsson",
    "Thorfinn",
    "Thorfinnsson",
    "Torvald",
    "Torvaldsson",
    "Ulf",
    "Ulfsson",
    "Valdimar",
    "Valdimarsson",
    "Vidar",
    "Vidarsson",
    "Vigfus",
    "Vigfusson",
    "Yngvar",
    "Yngvarsson",
    "Yngve",
    "Yngvesdottir",
    "Yngvesson",
]



female_names = [
    "Abigail",
    "Addison",
    "Adeline",
    "Alice",
    "Amelia",
    "Anna",
    "Aria",
    "Aubrey",
    "Audrey",
    "Aurora",
    "Autumn",
    "Ava",
    "Avery",
    "Bella",
    "Brooklyn",
    "Camila",
    "Caroline",
    "Charlotte",
    "Chloe",
    "Claire",
    "Clara",
    "Eleanor",
    "Elena",
    "Eliana",
    "Elizabeth",
    "Ella",
    "Ellie",
    "Emilia",
    "Emily",
    "Emma",
    "Eva",
    "Evelyn",
    "Everly",
    "Gabriella",
    "Gianna",
    "Grace",
    "Hadley",
    "Hannah",
    "Harper",
    "Hazel",
    "Isabella",
    "Isla",
    "Ivy",
    "Kinsley",
    "Layla",
    "Leah",
    "Lillian",
    "Lily",
    "Lucy",
    "Luna",
    "Lyla",
    "Madison",
    "Maya",
    "Mia",
    "Mila",
    "Natalie",
    "Nora",
    "Nova",
    "Olivia",
    "Paisley",
    "Penelope",
    "Quinn",
    "Reagan",
    "Riley",
    "Ruby",
    "Samantha",
    "Savannah",
    "Scarlett",
    "Skylar",
    "Sofia",
    "Sophia",
    "Stella",
    "Valentina",
    "Victoria",
    "Violet",
    "Vivian",
    "Zoe",
    "Zoey",
]

male_names = [
    "Aaron",
    "Adam",
    "Adrian",
    "Aiden",
    "Alexander",
    "Andrew",
    "Anthony",
    "Asher",
    "Benjamin",
    "Bryson",
    "Caleb",
    "Carter",
    "Charles",
    "Christopher",
    "Cole",
    "Cooper",
    "Damian",
    "Daniel",
    "David",
    "Dylan",
    "Edward",
    "Eli",
    "Elijah",
    "Ethan",
    "Ezra",
    "Gabriel",
    "Grayson",
    "Henry",
    "Hudson",
    "Hunter",
    "Ian",
    "Isaac",
    "Isaiah",
    "Jack",
    "Jackson",
    "Jacob",
    "James",
    "Jaxon",
    "Jayden",
    "John",
    "Jordan",
    "Joseph",
    "Joshua",
    "Josiah",
    "Julian",
    "Leo",
    "Levi",
    "Liam",
    "Lincoln",
    "Logan",
    "Lucas",
    "Luke",
    "Mason",
    "Mateo",
    "Matthew",
    "Micah",
    "Michael",
    "Miles",
    "Nathan",
    "Noah",
    "Nolan",
    "Oliver",
    "Owen",
    "Ryan",
    "Samuel",
    "Sebastian",
    "Theodore",
    "Thomas",
    "Weston",
    "William",
    "Wyatt",
    "Xavier",
]

surnames = [
    "Abbott",
    "Adams",
    "Adkins",
    "Aguilar",
    "Alexander",
    "Allen",
    "Alvarado",
    "Alvarez",
    "Anderson",
    "Andrews",
    "Armstrong",
    "Arnold",
    "Austin",
    "Avila",
    "Bailey",
    "Baker",
    "Baldwin",
    "Ball",
    "Ballard",
    "Banks",
    "Barber",
    "Barker",
    "Barnes",
    "Barnett",
    "Barrett",
    "Bass",
    "Bates",
    "Beard",
    "Beck",
    "Becker",
    "Bell",
    "Bennett",
    "Benson",
    "Berry",
    "Bishop",
    "Black",
    "Blair",
    "Blake",
    "Bowen",
    "Bowman",
    "Boyd",
    "Bradley",
    "Brady",
    "Brewer",
    "Briggs",
    "Brock",
    "Brooks",
    "Brown",
    "Bryant",
    "Buchanan",
    "Burgess",
    "Burke",
    "Burns",
    "Burton",
    "Bush",
    "Butler",
    "Byrd",
    "Caldwell",
    "Campbell",
    "Cannon",
    "Carlson",
    "Carpenter",
    "Carr",
    "Carroll",
    "Carter",
    "Castillo",
    "Castro",
    "Chambers",
    "Chandler",
    "Chapman",
    "Chavez",
    "Christensen",
    "Clark",
    "Clayton",
    "Cobb",
    "Cohen",
    "Cole",
    "Coleman",
    "Collins",
    "Colon",
    "Conner",
    "Cook",
    "Cooper",
    "Copeland",
    "Cox",
    "Craig",
    "Crawford",
    "Cross",
    "Cummings",
    "Cunningham",
    "Curry",
    "Curtis",
    "Dalton",
    "Daniel",
    "Daniels",
    "Davidson",
    "Davis",
    "Dawson",
    "Day",
    "Dean",
    "Delgado",
    "Dennis",
    "Diaz",
    "Dixon",
    "Douglas",
    "Doyle",
    "Drake",
    "Duncan",
    "Dunn",
    "Edwards",
    "Elliott",
    "Erickson",
    "Estrada",
    "Evans",
    "Farmer",
    "Ferguson",
    "Fernandez",
    "Fields",
    "Figures",
    "Fitzgerald",
    "Fleming",
    "Fletcher",
    "Flores",
    "Flowers",
    "Floyd",
    "Foster",
    "Fowler",
    "Fox",
    "Francis",
    "Frank",
    "Franklin",
    "Frazier",
    "Freeman",
    "French",
    "Fuller",
    "Garcia",
    "Gardner",
    "Garner",
    "Garrett",
    "Garza",
    "George",
    "Gibbs",
    "Gilbert",
    "Gill",
    "Glover",
    "Gonzales",
    "Gonzalez",
    "Goodman",
    "Goodwin",
    "Gordon",
    "Grant",
    "Graves",
    "Gray",
    "Green",
    "Greene",
    "Greer",
    "Gregory",
    "Griffin",
    "Griffith",
    "Gross",
    "Guerrero",
    "Gutierrez",
    "Guzman",
    "Hale",
    "Hall",
    "Hammond",
    "Hampton",
    "Hansen",
    "Hanson",
    "Hardy",
    "Harmon",
    "Harper",
    "Harris",
    "Hart",
    "Harvey",
    "Hawkins",
    "Hayes",
    "Haynes",
    "Henderson",
    "Henry",
    "Hernandez",
    "Herrera",
    "Hicks",
    "Higgins",
    "Hill",
    "Hines",
    "Hodges",
    "Hoffman",
    "Holland",
    "Holloway",
    "Holmes",
    "Holt",
    "Hopkins",
    "Horton",
    "Houston",
    "Howard",
    "Howell",
    "Hubbard",
    "Hudson",
    "Huff",
    "Hughes",
    "Hunt",
    "Hunter",
    "Ingram",
    "Jackson",
    "Jacobs",
    "James",
    "Jefferson",
    "Jenkins",
    "Jennings",
    "Jensen",
    "Jimenez",
    "Johnson",
    "Johnston",
    "Jones",
    "Joseph",
    "Keller",
    "Kelley",
    "Kelly",
    "Kennedy",
    "Kim",
    "King",
    "Klein",
    "Knight",
    "Lambert",
    "Lane",
    "Larson",
    "Lawrence",
    "Lawson",
    "Lee",
    "Leonard",
    "Lewis",
    "Lindsey",
    "Little",
    "Lloyd",
    "Logan",
    "Long",
    "Lopez",
    "Love",
    "Lowe",
    "Lucas",
    "Lynch",
    "Lyons",
    "Mack",
    "Maldonado",
    "Malone",
    "Mann",
    "Manning",
    "Marsh",
    "Martin",
    "Martinez",
    "Mason",
    "Massey",
    "Matthews",
    "Maxwell",
    "May",
    "Mcbride",
    "Mccarthy",
    "Mccormick",
    "Mccoy",
    "Mcdaniel",
    "Mcgee",
    "Mckinney",
    "Mclaughlin",
    "Medina",
    "Mendez",
    "Mendoza",
    "Meyer",
    "Miles",
    "Miller",
    "Mills",
    "Mitchell",
    "Montgomery",
    "Moody",
    "Moore",
    "Morales",
    "Moran",
    "Moreno",
    "Morgan",
    "Morris",
    "Morrison",
    "Morton",
    "Moss",
    "Mullins",
    "Munoz",
    "Murphy",
    "Murray",
    "Neal",
    "Nelson",
    "Newman",
    "Newton",
    "Nguyen",
    "Nichols",
    "Norman",
    "Norris",
    "Norton",
    "Nunez",
    "Obrien",
    "Oliver",
    "Olson",
    "Ortega",
    "Osborne",
    "Owen",
    "Padilla",
    "Page",
    "Palmer",
    "Park",
    "Parker",
    "Parks",
    "Parsons",
    "Patrick",
    "Patterson",
    "Patton",
    "Paul",
    "Payne",
    "Pearson",
    "Pena",
    "Perez",
    "Perkins",
    "Perry",
    "Peters",
    "Peterson",
    "Phillips",
    "Pierce",
    "Pittman",
    "Poole",
    "Pope",
    "Porter",
    "Potter",
    "Powell",
    "Powers",
    "Pratt",
    "Price",
    "Quinn",
    "Ramirez",
    "Ramos",
    "Ramsey",
    "Ray",
    "Reed",
    "Reese",
    "Reeves",
    "Reid",
    "Reyes",
    "Reynolds",
    "Rhodes",
    "Rice",
    "Richards",
    "Richardson",
    "Riley",
    "Rios",
    "Robbins",
    "Roberts",
    "Robertson",
    "Robinson",
    "Robles",
    "Rodgers",
    "Rodriguez",
    "Rodriquez",
    "Rogers",
    "Romero",
    "Rose",
    "Ross",
    "Rowe",
    "Roy",
    "Ruiz",
    "Russell",
    "Ryan",
    "Salazar",
    "Sanchez",
    "Sanders",
    "Sandoval",
    "Santiago",
    "Santos",
    "Saunders",
    "Schmidt",
    "Schneider",
    "Schultz",
    "Schwartz",
    "Scott",
    "Sharp",
    "Shaw",
    "Shelton",
    "Sherman",
    "Silva",
    "Simmons",
    "Simon",
    "Simpson",
    "Sims",
    "Smith",
    "Snyder",
    "Soto",
    "Sparks",
    "Spencer",
    "Stanley",
    "Steele",
    "Stephens",
    "Stevens",
    "Stevenson",
    "Stewart",
    "Stokes",
    "Stone",
    "Strickland",
    "Sutton",
    "Swanson",
    "Tate",
    "Taylor",
    "Terry",
    "Thomas",
    "Thompson",
    "Thornton",
    "Todd",
    "Torres",
    "Townsend",
    "Tucker",
    "Turner",
    "Tyler",
    "Valdez",
    "Vance",
    "Vargas",
    "Vasquez",
    "Vaughn",
    "Vega",
    "Wade",
    "Wagner",
    "Walker",
    "Walsh",
    "Walters",
    "Walton",
    "Ward",
    "Warner",
    "Warren",
    "Washington",
    "Waters",
    "Watkins",
    "Watson",
    "Watts",
    "Weaver",
    "Webb",
    "Weber",
    "Webster",
    "Welch",
    "Wells",
    "Wheeler",
    "White",
    "Williams",
    "Williamson",
    "Willis",
    "Wilson",
    "Wise",
    "Wolfe",
    "Wong",
    "Wood",
    "Wright",
    "Yates",
    "Young",
    "Zimmerman",
]

female_names_lbr = [
    "Ada",
    "Aelfgifu",
    "Aelfwynn",
    "Aethelflaed",
    "Aethelthryth",
    "Ailith",
    "Aislinn",
    "Alfgifu",
    "Althryth",
    "Alys",
    "Amina",
    "Anastasia",
    "Anwen",
    "Astrid",
    "Avelina",
    "Beatrix",
    "Benedicta",
    "Blanchefleur",
    "Bridget",
    "Catherine",
    "Cecily",
    "Clarice",
    "Cynethryth",
    "Diana",
    "Eadgyth",
    "Ealhswith",
    "Eanswith",
    "Edith",
    "Edyth",
    "Eleanor",
    "Elfleda",
    "Elfthryth",
    "Elgifu",
    "Elizabeth",
    "Emma",
    "Emmeline",
    "Enfleda",
    "Estrid",
    "Ethelfleda",
    "Eva",
    "Felicia",
    "Flora",
    "Freya",
    "Gisela",
    "Godiva",
    "Gormlaith",
    "Gundred",
    "Gwenllian",
    "Gwladys",
    "Gytha",
    "Hedwig",
    "Helena",
    "Hephzibah",
    "Herleva",
    "Hilda",
    "Hildegard",
    "Ida",
    "Isolde",
    "Iveta",
    "Joan",
    "Juliana",
    "Katherine",
    "Kensa",
    "Layla",
    "Leofgifu",
    "Leofwynn",
    "Leofytha",
    "Leonora",
    "Lilith",
    "Margaret",
    "Matilda",
    "Maud",
    "Millicent",
    "Morwenna",
    "Nesta",
    "Oda",
    "Odelina",
    "Olwen",
    "Osburga",
    "Osthryth",
    "Parnel",
    "Phyllis",
    "Ragnhild",
    "Rhiannon",
    "Rosamund",
    "Rowena",
    "Sabina",
    "Saffira",
    "Serena",
    "Sigrid",
    "Sybil",
    "Tatiana",
    "Thora",
    "Ursula",
    "Vigdis",
    "Winifred",
    "Wulfhilda",
    "Wulfwynn",
    "Ygraine",
    "Yseult",
    "Zenobia",
    "Zillah",
    "Zoe",
    "Zosia",
    "Zuleika",
    "Zuriel",
    "Zyanya",
    "Zyra",
]

male_names_lbr = [
    "Aethelwulf",
    "Alfred",
    "Aelfric",
    "Aelfstan",
    "Aelfwine",
    "Aethelbald",
    "Aethelbert",
    "Aethelred",
    "Aethelstan",
    "Aethelwold",
    "Aldhelm",
    "Beornheard",
    "Beornwulf",
    "Beowulf",
    "Brihtnoth",
    "Ceolwulf",
    "Cerdic",
    "Cuthbert",
    "Cynewulf",
    "Eadberht",
    "Eadfrith",
    "Eadgar",
    "Eadmund",
    "Eadred",
    "Eadric",
    "Eadweard",
    "Eadwig",
    "Ealdred",
    "Ealdwulf",
    "Eanflaed",
    "Eanred",
    "Ecgberht",
    "Ecgfrith",
    "Ecgwulf",
    "Edgar",
    "Edmund",
    "Edred",
    "Edric",
    "Edward",
    "Edwin",
    "Egbert",
    "Elfhere",
    "Elfric",
    "Ethelbert",
    "Ethelred",
    "Ethelstan",
    "Ethelwald",
    "Godfrey",
    "Godric",
    "Godwin",
    "Harold",
    "Hereward",
    "Hildred",
    "Hrothgar",
    "Leofric",
    "Leofwine",
    "Leofwulf",
    "Offa",
    "Osgood",
    "Oswald",
    "Oswin",
    "Oswulf",
    "Radulf",
    "Ragnald",
    "Siward",
    "Theobald",
    "Thurstan",
    "Wulfhere",
    "Wulfric",
    "Wulfstan",
    "Wulfrun",
    "Wulfweard",
    "Aldred",
    "Aldwin",
    "Aldwyn",
    "Alfgar",
    "Alfric",
    "Algar",
    "Alric",
    "Alwin",
    "Anselm",
    "Ansgar",
    "Anson",
    "Arnulf",
    "Athelstan",
    "Aubrey",
    "Baldric",
    "Baldwin",
    "Benedict",
    "Bernard",
    "Bertram",
    "Bertrand",
    "Bran",
    "Bruno",
    "Clement",
    "Conrad",
    "Cuthred",
    "Cwenbeorht",
    "Dagobert",
    "Dunstan",
    "Eadbald",
    "Eadberht",
    "Eadfrid",
    "Eadgar",
    "Eadmund",
    "Eadric",
    "Eadweard",
    "Eadwulf",
    "Ealdfrith",
    "Ealdhelm",
    "Ealdred",
    "Eanbald",
    "Eanfled",
    "Eardwulf",
    "Earnwulf",
    "Ecgbert",
    "Edgar",
    "Edmund",
    "Edred",
    "Edward",
    "Edwin",
    "Egfrid",
    "Elfric",
    "Elfstan",
    "Elfwine",
    "Ethelbald",
    "Ethelbert",
    "Ethelred",
    "Ethelstan",
    "Ethelwald",
    "Frederick",
    "Geoffrey",
    "Godric",
    "Godwin",
    "Gundulf",
    "Helmstan",
    "Hereward",
    "Herfrid",
    "Higbald",
    "Hildbrand",
    "Hrothbert",
    "Hunberht",
    "Hygbald",
    "Kenelm",
    "Leofgar",
    "Leofric",
    "Leofwine",
    "Leofwulf",
    "Ludwig",
    "Oswald",
    "Oswin",
    "Oswulf",
    "Radulf",
    "Ralph",
    "Randolph",
    "Reynard",
    "Richard",
    "Robert",
    "Rodbert",
    "Sebastian",
    "Sigfrid",
    "Sigurd",
    "Swain",
    "Thurstan",
    "Tobias",
    "Ulric",
    "Waldred",
    "Walfrid",
    "Waldric",
    "Wido",
    "Wigmund",
    "Wigstan",
    "Wilfrid",
    "Wilibald",
    "William",
    "Wilmot",
    "Winfred",
    "Winfrith",
    "Winston",
    "Wulfhere",
]

surnames_lbr = [
    "Abbey",
    "Alden",
    "Ashby",
    "Bancroft",
    "Barlow",
    "Beaumont",
    "Bingham",
    "Birch",
    "Blackwood",
    "Blakely",
    "Bramley",
    "Briarwood",
    "Brockley",
    "Burrows",
    "Chadwick",
    "Chalmers",
    "Clayton",
    "Cromwell",
    "Davenport",
    "Dunstan",
    "Eastwood",
    "Fairchild",
    "Falkner",
    "Farley",
    "Fletcher",
    "Gainsborough",
    "Gardner",
    "Gilbert",
    "Granger",
    "Hadley",
    "Hawthorne",
    "Hayward",
    "Hemsworth",
    "Hensley",
    "Hollis",
    "Huntington",
    "Ingram",
    "Jefferson",
    "Kensington",
    "Kingsley",
    "Langley",
    "Larkspur",
    "Lockwood",
    "Manning",
    "Marlowe",
    "Montgomery",
    "Moss",
    "Norwood",
    "Oswald",
    "Pembroke",
    "Preston",
    "Radcliffe",
    "Rutherford",
    "Salisbury",
    "Sheffield",
    "Sherwood",
    "Stanford",
    "Sutton",
    "Tennyson",
    "Thackeray",
    "Thornton",
    "Tilden",
    "Underwood",
    "Walden",
    "Warren",
    "Wellington",
    "Westbrook",
    "Whitaker",
    "Wickham",
    "Willoughby",
    "Winchester",
    "Woodcroft",
    "Wycliffe",
    "Yardley",
    "Abbott",
    "Ainsworth",
    "Archer",
    "Atwood",
    "Baker",
    "Barton",
    "Bennett",
    "Bolton",
    "Bradford",
    "Brewster",
    "Bridges",
    "Buckley",
    "Burton",
    "Chandler",
    "Clarke",
    "Cooper",
    "Cunningham",
    "Darby",
    "Dawson",
    "Delaney",
    "Dixon",
    "Eaton",
    "Fisher",
    "Foster",
    "Gibson",
    "Graham",
    "Hammond",
    "Harrison",
    "Hawkins",
    "Hilton",
    "Hudson",
    "Jackson",
    "Kendall",
    "Knight",
    "Lawson",
    "Mackenzie",
    "Miller",
    "Nelson",
    "Oliver",
    "Palmer",
    "Parker",
    "Potter",
    "Reynolds",
    "Roberts",
    "Rowland",
    "Scott",
    "Shelley",
    "Sinclair",
    "Spencer",
    "Stone",
    "Sullivan",
    "Taylor",
    "Walker",
    "Webster",
    "Wheeler",
    "Wilson",
    "Wright",
    "Young",
    "Ashton",
    "Banks",
    "Beckett",
    "Bolton",
    "Bowers",
    "Brady",
    "Brock",
    "Butler",
    "Carter",
    "Coleman",
    "Conway",
    "Crawford",
    "Crosby",
    "Dalton",
    "Daniels",
    "Darcy",
    "Davenport",
    "Dawson",
    "Devereux",
    "Drake",
    "Dunn",
    "Edwards",
    "Ellis",
    "Fletcher",
    "Francis",
    "Garner",
    "Griffiths",
    "Hamilton",
    "Harper",
    "Hayes",
    "Holland",
    "Hopkins",
    "Hughes",
    "Hutchinson",
    "Jackson",
    "Jordan",
    "Kingsley",
    "Lawrence",
    "Lloyd",
    "Mason",
    "Maynard",
    "Morrison",
    "Newton",
    "Nicholson",
    "O'Connor",
    "Perry",
    "Porter",
    "Quinn",
    "Reeves",
    "Rice",
    "Robinson",
    "Sawyer",
    "Shaw",
    "Simmons",
    "Stewart",
    "Sullivan",
    "Tate",
    "Thompson",
    "Turner",
    "Wade",
    "Watkins",
]



female_prefix = [
    "ber",
    "bri",
    "cla",
    "cor",
    "dal",
    "dor",
    "el",
    "fro",
    "gol",
    "har",
    "hil",
    "lav",
    "lil",
    "lo",
    "mar",
    "mel",
    "nar",
    "nor",
    "ol",
    "per",
    "pip",
    "ro",
    "sam",
    "san",
    "syl",
    "tas",
    "wil",
]

female_suffix = [
    "a",
    "adoc",
    "ald",
    "bella",
    "belle",
    "dora",
    "ella",
    "elle",
    "freda",
    "gwen",
    "la",
    "lea",
    "lina",
    "lla",
    "lotta",
    "ma",
    "mia",
    "mina",
    "mira",
    "na",
    "nelle",
    "nna",
    "ra",
    "ri",
    "ria",
    "rie",
    "rina",
    "sa",
    "sella",
    "sie",
    "sy",
    "ta",
    "tina",
    "wyn",
]

male_prefix = [
    "albo",
    "bal",
    "bil",
    "bran",
    "con",
    "dodo",
    "ever",
    "fal",
    "fer",
    "fin",
    "gaf",
    "gim",
    "gol",
    "ham",
    "hob",
    "las",
    "leo",
    "lim",
    "lobo",
    "mar",
    "milo",
    "mung",
    "nico",
    "odo",
    "olbo",
    "pal",
    "per",
    "pim",
    "pip",
    "rolo",
    "ruf",
    "sam",
    "silbo",
    "tob",
    "ugo",
    "vigo",
    "wigo",
    "wim",
    "wise",
    "wolbo",
]

male_suffix = [
    "bo",
    "bri",
    "do",
    "dro",
    "fast",
    "fer",
    "gar",
    "go",
    "grin",
    "hard",
    "lo",
    "man",
    "mo",
    "nac",
    "nard",
    "nibo",
    "no",
    "per",
    "pin",
    "po",
    "ric",
    "rim",
    "ro",
    "san",
    "sim",
    "to",
    "wise",
]

surname_prefix = [
    "bagg",
    "bran",
    "bur",
    "cra",
    "cud",
    "good",
    "green",
    "hard",
    "hay",
    "hill",
    "le",
    "long",
    "merry",
    "oak",
    "old",
    "pere",
    "pip",
    "proud",
    "sack",
    "small",
    "tall",
    "took",
    "toss",
    "under",
    "whit",
]

surname_suffix = [
    "bottom",
    "buckle",
    "burr",
    "by",
    "digger",
    "foot",
    "girdle",
    "hair",
    "hobb",
    "ins",
    "kins",
    "leaf",
    "man",
    "over",
    "pint",
    "root",
    "shire",
    "thistle",
    "top",
    "wag",
    "ward",
    "wheat",
    "wort",
    "worthy",
]

female_names = [
    "Aelia",
    "Aemilia",
    "Alba",
    "Alira",
    "Amarylle",
    "Andrella",
    "Antonia",
    "Anysa",
    "Aquila",
    "Arula",
    "Augusta",
    "Aurelia",
    "Aurelius",
    "Aurora",
    "Avonelle",
    "Bellona",
    "Blossom",
    "Briella",
    "Caecilia",
    "Caelia",
    "Calinda",
    "Camilla",
    "Cassia",
    "Cecilia",
    "Celandra",
    "Celinda",
    "Ceridwen",
    "Cheribelle",
    "Clementia",
    "Cora",
    "Coralia",
    "Corisande",
    "Cornelia",
    "Daisy",
    "Dandelea",
    "Dellanna",
    "Diamanda",
    "Diana",
    "Dinella",
    "Domitia",
    "Dorinda",
    "Drusilla",
    "Eirlys",
    "Elara",
    "Elfinia",
    "Elora",
    "Elowyn",
    "Ember",
    "Endellion",
    "Epona",
    "Estella",
    "Fabiola",
    "Faeryn",
    "Faustina",
    "Faylinn",
    "Fenella",
    "Fiametta",
    "Flavia",
    "Fleur",
    "Floriana",
    "Fortuna",
    "Gemma",
    "Goldie",
    "Harmony",
    "Hazel",
    "Honeysuckle",
    "Idony",
    "Irisa",
    "Isolde",
    "Ivy",
    "Jewel",
    "Julia",
    "Justina",
    "Kerensa",
    "Laurentia",
    "Lavender",
    "Lavinia",
    "Leilani",
    "Lilias",
    "Livia",
    "Lorelei",
    "Lucilla",
    "Lucretia",
    "Lumina",
    "Lyric",
    "Maebry",
    "Marcella",
    "Marcia",
    "Marigold",
    "Marina",
    "Maxima",
    "Melantha",
    "Merryn",
    "Mila",
    "Mirabelle",
    "Misty",
    "Morgana",
    "Nerissa",
    "Nessa",
    "Nimue",
    "Octavia",
    "Olivine",
    "Opaline",
    "Orchid",
    "Oriana",
    "Paulina",
    "Peony",
    "Periwinkle",
    "Petal",
    "Petronia",
    "Pippin",
    "Poppy",
    "Portia",
    "Prima",
    "Primrose",
    "Quincy",
    "Rosalind",
    "Rowan",
    "Sabina",
    "Sabrina",
    "Saffron",
    "Samantha",
    "Sapphire",
    "Secundia",
    "Septima",
    "Seraphina",
    "Serena",
    "Shaylee",
    "Silvana",
    "Sorrel",
    "Stella",
    "Sylvia",
    "Tansy",
    "Tatiana",
    "Tertulla",
    "Tessera",
    "Thalia",
    "Titania",
    "Trillium",
    "Twyla",
    "Valentina",
    "Valeria",
    "Velia",
    "Verina",
    "Vesper",
    "Vibia",
    "Victoria",
    "Violetta",
    "Vita",
    "Willa",
    "Wisteria",
    "Yara",
    "Zephyrine",
    "Zinnia",
    "Zoe",
]

male_names = [
    "Adalman",
    "Aldern",
    "Alric",
    "Arro",
    "Balwin",
    "Barmund",
    "Beldon",
    "Bellis",
    "Beren",
    "Bifur",
    "Bolbo",
    "Bolger",
    "Brumley",
    "Bungo",
    "Calaman",
    "Carrot",
    "Cedric",
    "Cotton",
    "Dalman",
    "Dandy",
    "Deagol",
    "Doderic",
    "Donnegan",
    "Drogo",
    "Dudo",
    "Dundoc",
    "Dunny",
    "Elmer",
    "Elrond",
    "Elwis",
    "Falco",
    "Fastolph",
    "Filibert",
    "Fosco",
    "Frodo",
    "Gaffer",
    "Galahad",
    "Gerontius",
    "Gilly",
    "Ginger",
    "Gord",
    "Griffo",
    "Halfred",
    "Halson",
    "Hamfast",
    "Hamson",
    "Happylegs",
    "Harfoot",
    "Hending",
    "Hob",
    "Hobson",
    "Holfast",
    "Holman",
    "Hornblower",
    "Ingle",
    "Isembard",
    "Jago",
    "Kithran",
    "Largo",
    "Lobelia",
    "Lotho",
    "Madoc",
    "Marmaduke",
    "Masterful",
    "Milo",
    "Minto",
    "Mungo",
    "Nibs",
    "Nob",
    "Odo",
    "Olo",
    "Otho",
    "Paladin",
    "Pearlman",
    "Peregrin",
    "Pervinca",
    "Podo",
    "Posco",
    "Proudfoot",
    "Reginard",
    "Robin",
    "Roderic",
    "Roper",
    "Ruddy",
    "Rufus",
    "Samwise",
    "Sancho",
    "Saradoc",
    "Sigismond",
    "Togo",
    "Tolman",
    "Tom",
    "Tubbo",
    "Tulip",
    "Wilcome",
    "Wilibald",
    "Wilwarin",
    "Wiseacre",
    "Wort",
    "Wylis",
    "Yapper",
    "Yazoo",
    "Yogo",
    "Yule",
    "Yves",
    "Zam",
    "Zeff",
    "Zinn",
    "Zook",
]

surnames = [
    "Amberstone",
    "Applebrook",
    "Applegrove",
    "Auburnleaf",
    "Badgerhill",
    "Barleyfoot",
    "Berrybottom",
    "Birchwood",
    "Bluebell",
    "Bottlehill",
    "Bramblebush",
    "Brightmeadow",
    "Bumbleberry",
    "Burrystone",
    "Buttercup",
    "Candlewick",
    "Chestnut",
    "Cinderfoot",
    "Cobblehill",
    "Copperfield",
    "Copperknob",
    "Crickhollow",
    "Dandelion",
    "Dewberry",
    "Dewdrop",
    "Dillyhill",
    "Driftwood",
    "Eveningshade",
    "Fallowfield",
    "Feathergale",
    "Fernbrook",
    "Fernshadow",
    "Firelight",
    "Frostwhisper",
    "Gingerroot",
    "Goldberry",
    "Goldenleaf",
    "Gooseberry",
    "Gorseblossom",
    "Grasshopper",
    "Greenbottle",
    "Harvestmoon",
    "Hazelnut",
    "Heathertoes",
    "Hedgegrove",
    "Hobblefoot",
    "Hobbleknee",
    "Hollyberry",
    "Hollywhistle",
    "Honeydew",
    "Honeythorn",
    "Ironbeard",
    "Jasmine",
    "Jingletoe",
    "Kettlewhistle",
    "Larkspur",
    "Lavender",
    "Leafspring",
    "Lilybrook",
    "Littleberry",
    "Meadowsweet",
    "Merryman",
    "Milkweed",
    "Mistyspring",
    "Morningdew",
    "Mossleaf",
    "Mossybrook",
    "Mumblefoot",
    "Nightrunner",
    "Nimblefingers",
    "Nutmeg",
    "Oakendale",
    "Oakentoe",
    "Peachblossom",
    "Pebblebrook",
    "Pickleberry",
    "Picklefoot",
    "Potterspring",
    "Primrose",
    "Puddlefoot",
    "Pumpkinpatch",
    "Quicksilver",
    "Quietstream",
    "Radishbottom",
    "Redcheek",
    "Ripplebrook",
    "Riverstone",
    "Roosterfoot",
    "Rosedale",
    "Rosepetal",
    "Sageleaf",
    "Sandybanks",
    "Shadetree",
    "Shepherd",
    "Shimmerleaf",
    "Shortstocking",
    "Silverbell",
    "Silverleaf",
    "Skiprock",
    "Sleepyeyes",
    "Snickerdoodle",
    "Snugglebottom",
    "Songbird",
    "Sparkleberry",
    "Spiderwick",
    "Spindlewick",
    "Springdale",
    "Squirrelwhisker",
    "Starflower",
    "Starrynight",
    "Stoutfoot",
    "Strawberry",
    "Sunbeam",
    "Sweetwater",
    "Talltree",
    "Tanglethorn",
    "Tawnyberry",
    "Thistlebrook",
    "Thistletop",
    "Tinderwick",
    "Tinypocket",
    "Treetop",
    "Tricklebrook",
    "Tumblestone",
    "Tumbleweed",
    "Twilight",
    "Twinkletoes",
    "Wagglebottom",
    "Weedwhistle",
    "Wellington",
    "Wheatgrass",
    "Whisperingwind",
    "Whisperwind",
    "Wildflower",
    "Wildfoot",
    "Willowbrook",
    "Willowhollow",
    "Woodchuck",
    "Woodruff",
    "Woolysocks",
    "Yarrowroot",
    "Yewshade",
    "Zephyrdale",
    "Zinnia",
]



male_prefix = [
    "aer",
    "ald",
    "an",
    "ar",
    "bar",
    "bor",
    "cal",
    "dal",
    "dan",
    "dur",
    "ed",
    "eld",
    "er",
    "fal",
    "fin",
    "gal",
    "gan",
    "gar",
    "had",
    "hal",
    "ian",
    "in",
    "kar",
    "kor",
    "lanc",
    "mar",
    "mer",
    "nor",
    "or",
    "rad",
    "ran",
    "ron",
    "sar",
    "sol",
    "tan",
    "thor",
    "tor",
    "ul",
    "val",
    "van",
    "vor",
    "wal",
    "war",
    "yor",
    "zar",
]

male_suffix = [
    "ald",
    "an",
    "ar",
    "ard",
    "bar",
    "dan",
    "dor",
    "dred",
    "dur",
    "fin",
    "gald",
    "gan",
    "gar",
    "hard",
    "horn",
    "ian",
    "ion",
    "lan",
    "mir",
    "nard",
    "or",
    "rad",
    "ran",
    "ric",
    "rin",
    "ron",
    "thor",
    "thorn",
    "und",
    "val",
    "var",
    "ward",
    "win",
    "wood",
    "wyn",
    "yar",
]

female_prefix = [
    "ad",
    "al",
    "an",
    "ar",
    "bel",
    "ca",
    "cel",
    "da",
    "di",
    "el",
    "en",
    "fa",
    "fay",
    "gal",
    "gi",
    "ha",
    "hel",
    "il",
    "in",
    "ja",
    "kel",
    "la",
    "le",
    "ma",
    "mi",
    "na",
    "ni",
    "ol",
    "pe",
    "qui",
    "ra",
    "re",
    "sa",
    "se",
    "ta",
    "thi",
    "va",
    "ve",
    "wil",
    "ya",
    "ze",
]

female_suffix = [
    "a",
    "ana",
    "ara",
    "beth",
    "cia",
    "da",
    "dea",
    "elle",
    "fa",
    "ga",
    "hilda",
    "ia",
    "iana",
    "ida",
    "ira",
    "la",
    "lia",
    "lina",
    "ma",
    "mia",
    "na",
    "nelle",
    "nia",
    "ra",
    "ria",
    "sa",
    "sia",
    "ta",
    "thea",
    "thia",
    "va",
    "via",
    "ya",
]

surname_prefix = [
    "ald",
    "arn",
    "bar",
    "ber",
    "brand",
    "carr",
    "cor",
    "dun",
    "eag",
    "eld",
    "fair",
    "gar",
    "gold",
    "han",
    "haw",
    "helm",
    "kings",
    "long",
    "oak",
    "rav",
    "red",
    "river",
    "rock",
    "silver",
    "stone",
    "thorn",
    "west",
    "white",
    "wind",
    "wynd",
    "yar",
    "zel",
    "al",
    "an",
    "ark",
    "ash",
    "ba",
    "bor",
    "be",
    "bel",
    "car",
    "cas",
    "cor",
    "dar",
    "de",
    "del",
    "di",
    "dor",
    "el",
    "er",
    "fal",
]

surname_suffix = [
    "bourne",
    "bridge",
    "brook",
    "castle",
    "field",
    "ford",
    "ham",
    "hurst",
    "lake",
    "ley",
    "mead",
    "mill",
    "shire",
    "stead",
    "stone",
    "ton",
    "view",
    "wall",
    "ward",
    "water",
    "well",
    "wick",
    "worth",
    "bay",
    "crest",
    "croft",
    "dale",
    "gate",
    "glen",
    "haven",
    "hill",
    "holme",
    "isle",
    "keep",
    "mere",
    "moor",
    "peak",
    "pool",
    "reach",
    "rise",
    "shade",
    "slope",
    "thorpe",
    "vale",
    "village",
    "weir",
    "wood",
    "yard",
    "zeal",
]

female_names = [
    "Adelaine",
    "Aeliana",
    "Aella",
    "Aeris",
    "Alandra",
    "Aldith",
    "Amara",
    "Amra",
    "Andralyn",
    "Anwyn",
    "Aquila",
    "Araluen",
    "Aravia",
    "Aria",
    "Ariantha",
    "Ariella",
    "Asteria",
    "Astrid",
    "Aurelia",
    "Aveth",
    "Beleth",
    "Belisara",
    "Brynhild",
    "Calanthe",
    "Calithra",
    "Calliope",
    "Carys",
    "Cassia",
    "Celandine",
    "Celestia",
    "Cerelia",
    "Coralie",
    "Corinna",
    "Cressida",
    "Daela",
    "Damaris",
    "Darielle",
    "Delmira",
    "Eirini",
    "Eirlys",
    "Elara",
    "Elariel",
    "Elira",
    "Elowen",
    "Elysande",
    "Elysia",
    "Emeldis",
    "Evangeline",
    "Faela",
    "Faralia",
    "Felina",
    "Fenella",
    "Fiorella",
    "Galatea",
    "Galitha",
    "Gwenara",
    "Gwyneira",
    "Havilah",
    "Helia",
    "Heliana",
    "Idony",
    "Idranel",
    "Iliana",
    "Ilmira",
    "Imralda",
    "Isabeau",
    "Ismira",
    "Isolde",
    "Jesmina",
    "Jocasta",
    "Junia",
    "Kaelynn",
    "Kalina",
    "Kalypso",
    "Kerensa",
    "Keridwen",
    "Laelia",
    "Larissa",
    "Leandra",
    "Leliana",
    "Lilith",
    "Lorelei",
    "Lorilda",
    "Lyra",
    "Maelis",
    "Maelisande",
    "Maelora",
    "Marella",
    "Maren",
    "Marigold",
    "Mavria",
    "Melantha",
    "Melia",
    "Melisande",
    "Melora",
    "Mirith",
    "Nephele",
    "Nerina",
    "Nerissa",
    "Nimiane",
    "Nyx",
    "Ophelia",
    "Oriana",
    "Oriella",
    "Perenelle",
    "Persephone",
    "Phaedra",
    "Quelira",
    "Ravenna",
    "Ravina",
    "Rhea",
    "Rhiana",
    "Rhoslyn",
    "Rhoswen",
    "Sapphira",
    "Sarilda",
    "Selara",
    "Selena",
    "Selene",
    "Seraphina",
    "Seraphine",
    "Shalara",
    "Talitha",
    "Tallis",
    "Tamsin",
    "Thais",
    "Thalara",
    "Thalia",
    "Thamara",
    "Valencia",
    "Valeria",
    "Valoria",
    "Vesmira",
    "Vespera",
    "Violetta",
    "Xanthe",
    "Yarilda",
    "Ysabeau",
    "Zara",
    "Zephyra",
    "Zephyrine",
    "Zinnia",
    "Zirel",
]

male_names = [
    "Alaric",
    "Alberic",
    "Alden",
    "Aldon",
    "Aldric",
    "Alric",
    "Alwin",
    "Arland",
    "Armand",
    "Armin",
    "Arnold",
    "Arnor",
    "Arnulf",
    "Balder",
    "Baldric",
    "Balric",
    "Balrik",
    "Baradan",
    "Bard",
    "Bardulf",
    "Baron",
    "Beldor",
    "Bertram",
    "Berwin",
    "Borin",
    "Boromir",
    "Brandar",
    "Bromir",
    "Cadmus",
    "Caldor",
    "Calwin",
    "Caradoc",
    "Caranthir",
    "Caspian",
    "Cedric",
    "Colman",
    "Corbin",
    "Cormac",
    "Corwin",
    "Dagmar",
    "Dagobert",
    "Damrod",
    "Darius",
    "Delwin",
    "Derwin",
    "Dorin",
    "Dunstan",
    "Eadric",
    "Eadwin",
    "Edgar",
    "Edric",
    "Edwin",
    "Eldric",
    "Elric",
    "Elrond",
    "Elwin",
    "Emeric",
    "Emmerich",
    "Emrick",
    "Emrys",
    "Erland",
    "Falcon",
    "Faldor",
    "Faramir",
    "Faramond",
    "Fergus",
    "Finarfin",
    "Frederic",
    "Frithwald",
    "Garrick",
    "Gawain",
    "Gellert",
    "Gerwin",
    "Gil-galad",
    "Gilbert",
    "Gildor",
    "Gorbad",
    "Gorlim",
    "Grimbold",
    "Grimric",
    "Grimwald",
    "Hadrian",
    "Hadric",
    "Hadwin",
    "Haldor",
    "Halric",
    "Hammond",
    "Hamric",
    "Harmond",
    "Harrow",
    "Helmund",
    "Helwin",
    "Hermund",
    "Hilbert",
    "Holman",
    "Ingmar",
    "Ingold",
    "Ingolf",
    "Isengar",
    "Isengrim",
    "Isenwald",
    "Isildur",
    "Jareth",
    "Jarlath",
    "Jarngrim",
    "Kaelan",
    "Kelvin",
    "Kendric",
    "Kendrick",
    "Kormac",
    "Korwin",
    "Lander",
    "Landon",
    "Leofric",
    "Leofwin",
    "Leomund",
    "Letholdus",
    "Lorand",
    "Lorcan",
    "Maldon",
    "Maldred",
    "Maldric",
    "Marwin",
    "Meriadoc",
    "Merrick",
    "Merry",
    "Mirbrand",
    "Mirik",
    "Miron",
    "Nevron",
    "Norbert",
    "Norwin",
    "Osgar",
    "Osmund",
    "Osric",
    "Oswald",
    "Oswin",
    "Othmar",
    "Radagast",
    "Radulf",
    "Ragnor",
    "Randulf",
    "Reginald",
    "Rexmond",
    "Rexmund",
    "Roderic",
    "Roderick",
    "Rodrick",
    "Rohirrim",
    "Roland",
    "Romar",
    "Samwell",
    "Samwise",
    "Saradoc",
    "Saruman",
    "Sigmar",
    "Sigurd",
    "Silmaril",
    "Sorin",
    "Talbot",
    "Talwin",
    "Targon",
    "Tarmon",
    "Tarmond",
    "Tarwin",
    "Thedric",
    "Theobald",
    "Theodoric",
    "Thorin",
    "Thorondor",
    "Tobias",
    "Torald",
    "Torwin",
    "Uldred",
    "Uldric",
    "Ulric",
    "Valandil",
    "Valdan",
    "Valdric",
    "Walden",
    "Walder",
    "Waldon",
    "Waldric",
    "Wilfred",
    "Wilhelm",
    "Willard",
    "Yoric",
    "Yorick",
    "Yorin",
    "Zander",
    "Zephram",
    "Zephyr",
    "Zephyrus",
]

surnames = [
    "of Angmar",
    "of Annúminas",
    "of Anor",
    "of Barad-dûr",
    "of Belegost",
    "of Bree",
    "of Carn Dûm",
    "of Dale",
    "of Dol Amroth",
    "of Dol Guldur",
    "of Dorwinion",
    "of Dunland",
    "of Edoras",
    "of Emyn Muil",
    "of Enedwaith",
    "of Erebor",
    "of Eregion",
    "of Esgaroth",
    "of Fangorn",
    "of Far Harad",
    "of Forlindon",
    "of Fornost",
    "of Forochel",
    "of Gondor",
    "of Gundabad",
    "of Harad",
    "of Harlindon",
    "of Harondor",
    "of Helm's Deep",
    "of Isengard",
    "of Ithilien",
    "of Khand",
    "of Lorien",
    "of Lothlórien",
    "of Minas Tirith",
    "of Mirkwood",
    "of Mithlond",
    "of Moria",
    "of Mount Gundabad",
    "of Nargothrond",
    "of Near Harad",
    "of Orthanc",
    "of Osgiliath",
    "of Rhovanion",
    "of Rhûn",
    "of Rivendell",
    "of Rohan",
    "of Thranduil's Halls",
    "of Umbar",
    "of Withered Heath",
    "of the Grey Havens",
    "of the Shire",
]



female_prefix = [
    "agá",
    "aléx",
    "amphí",
    "aná",
    "arí",
    "athén",
    "démé",
    "élektr",
    "eurydí",
    "euthén",
    "galát",
    "harmón",
    "hébé",
    "hér",
    "kalí",
    "kleió",
    "kyprí",
    "lét",
    "méliss",
    "nér",
    "orestí",
    "pandór",
    "penél",
    "perí",
    "philómél",
    "pó",
    "thál",
    "théod",
    "xén",
]

female_suffix = [
    "a",
    "anthe",
    "dóra",
    "eia",
    "éne",
    "essa",
    "ia",
    "idóra",
    "ika",
    "inia",
    "ipé",
    "ithéa",
    "íne",
    "ita",
    "oé",
    "óra",
    "otea",
    "óti",
    "oula",
    "phén",
    "phíne",
    "phrón",
    "séa",
    "théa",
    "théne",
    "tía",
    "tra",
    "tía",
    "ydia",
]

male_prefix = [
    "aeg",
    "aer",
    "alex",
    "amph",
    "an",
    "anat",
    "and",
    "ant",
    "arch",
    "arist",
    "astr",
    "calli",
    "chr",
    "chrys",
    "cle",
    "cyr",
    "dam",
    "dem",
    "dion",
    "eir",
    "eugen",
    "euph",
    "her",
    "herm",
    "hip",
    "hipp",
    "kal",
    "klei",
    "leon",
    "lys",
    "megas",
    "myr",
    "neo",
    "nik",
    "olym",
    "pan",
    "per",
    "phil",
    "pho",
    "pol",
    "pyth",
    "soph",
    "theo",
    "theod",
    "xan",
    "xen",
    "zen",
]

male_suffix = [
    "ades",
    "ander",
    "archos",
    "as",
    "asios",
    "ax",
    "axos",
    "eides",
    "enios",
    "eochos",
    "eokles",
    "eon",
    "eris",
    "es",
    "ias",
    "ides",
    "ikles",
    "ion",
    "ios",
    "is",
    "kleis",
    "kles",
    "kriti",
    "lon",
    "lykos",
    "medes",
    "mon",
    "mos",
    "on",
    "or",
    "oris",
    "os",
    "otes",
    "otis",
    "ox",
    "oxenos",
    "oxis",
    "pheles",
    "phoros",
    "ptolemeos",
    "rakles",
    "ros",
    "ruthios",
    "sthenes",
    "stratos",
    "teles",
    "tides",
    "tor",
    "us",
    "xander",
    "xandros",
    "xenos",
    "xion",
    "xiphos",
    "ylos",
    "zenos",
]

surname_prefix = [
    "ae",
    "al",
    "an",
    "ap",
    "ar",
    "as",
    "ch",
    "di",
    "el",
    "en",
    "ep",
    "eu",
    "gl",
    "hy",
    "id",
    "is",
    "ka",
    "kr",
    "ly",
    "ma",
    "ne",
    "ny",
    "ol",
    "op",
    "or",
    "pe",
    "ph",
    "pl",
    "py",
    "rh",
    "sy",
    "th",
    "ti",
    "xy",
    "ze",
    "zo",
]

surname_suffix = [
    "dakis",
    "doros",
    "kis",
    "kides",
    "kis",
    "kos",
    "lidis",
    "los",
    "machos",
    "mides",
    "mos",
    "nadis",
    "nidis",
    "nomos",
    "padis",
    "pidis",
    "poulos",
    "reios",
    "ridis",
    "rinos",
    "rolos",
    "sidis",
    "sis",
    "skis",
    "solis",
    "sos",
    "tos",
    "tridis",
    "xidis",
    "zos",
]

female_names = [
    "Acacia",
    "Aella",
    "Agape",
    "Agatha",
    "Aglaia",
    "Aithra",
    "Alcestis",
    "Alcyone",
    "Alethea",
    "Alexandra",
    "Alexandria",
    "Althaia",
    "Althea",
    "Amalthea",
    "Amara",
    "Amarantha",
    "Amarillis",
    "Amphitrite",
    "Anais",
    "Anastasia",
    "Anatolia",
    "Andromache",
    "Andromeda",
    "Angeliki",
    "Anthea",
    "Antigone",
    "Aphrodite",
    "Apollonia",
    "Arete",
    "Ariadne",
    "Arista",
    "Artemis",
    "Aspasia",
    "Aster",
    "Asteria",
    "Astraea",
    "Astrid",
    "Atalanta",
    "Athena",
    "Aurelia",
    "Calantha",
    "Calliope",
    "Callista",
    "Calypso",
    "Cassandra",
    "Cassia",
    "Chloe",
    "Circe",
    "Cleopatra",
    "Clio",
    "Corinna",
    "Coronis",
    "Cybele",
    "Damaris",
    "Danae",
    "Daphne",
    "Daphnis",
    "Daria",
    "Delia",
    "Demeter",
    "Demetra",
    "Despina",
    "Despoina",
    "Diana",
    "Diantha",
    "Dido",
    "Dione",
    "Dorothea",
    "Eirene",
    "Elara",
    "Eleanor",
    "Elektra",
    "Elena",
    "Elene",
    "Eleni",
    "Elpis",
    "Elysia",
    "Elysse",
    "Eos",
    "Ephigenia",
    "Eudora",
    "Eugenia",
    "Eunice",
    "Euphemia",
    "Eurydice",
    "Evadne",
    "Evangelia",
    "Evanthe",
    "Faidra",
    "Faye",
    "Gaia",
    "Galatea",
    "Galene",
    "Halia",
    "Hecuba",
    "Helen",
    "Helena",
    "Helia",
    "Hera",
    "Hermia",
    "Hermione",
    "Hero",
    "Idalia",
    "Ifigeneia",
    "Iolanthe",
    "Ione",
    "Iphigenia",
    "Irene",
    "Iris",
    "Isabella",
    "Isadora",
    "Isidora",
    "Jocasta",
    "Juno",
    "Kalliope",
    "Kallista",
    "Kallisto",
    "Kallistrate",
    "Kassandra",
    "Katerina",
    "Kirrily",
    "Kleio",
    "Kleonike",
    "Klotho",
    "Kynthia",
    "Kyra",
    "Kyriaki",
    "Lamia",
    "Larisa",
    "Larissa",
    "Lavinia",
    "Leandra",
    "Leda",
    "Ligeia",
    "Lydia",
    "Lyra",
    "Lysandra",
    "Maia",
    "Margarita",
    "Medea",
    "Melaina",
    "Melantha",
    "Melia",
    "Melina",
    "Melissa",
    "Melitta",
    "Naida",
    "Narcissa",
    "Nausicaa",
    "Nefeli",
    "Nephele",
    "Nerissa",
    "Nike",
    "Nikola",
    "Nikolina",
    "Nyx",
    "Oceana",
    "Olympia",
    "Olympias",
    "Ophelia",
    "Orion",
    "Pallas",
    "Pandora",
    "Penelope",
    "Perdita",
    "Persephone",
    "Phaedra",
    "Philippa",
    "Philomena",
    "Philothea",
    "Phoebe",
    "Polyxena",
    "Rhea",
    "Rhodanthe",
    "Rhode",
    "Sappho",
    "Selene",
    "Sophia",
    "Thais",
    "Thalia",
    "Thea",
    "Theodora",
    "Theodosia",
    "Theophania",
    "Theresa",
    "Thetis",
    "Urania",
    "Ursula",
    "Xanthe",
    "Xenia",
    "Yolanda",
    "Zara",
    "Zenobia",
    "Zephyra",
    "Zoe",
]

male_names = [
    "Achaeus",
    "Achilles",
    "Adonis",
    "Adrastos",
    "Aeneas",
    "Aeschylus",
    "Aetios",
    "Agamemnon",
    "Agapetos",
    "Agapios",
    "Agatharchos",
    "Agathias",
    "Agathon",
    "Ajax",
    "Alcibiades",
    "Alcimedon",
    "Alexander",
    "Alexandros",
    "Alkibiades",
    "Alpheus",
    "Amphion",
    "Anaxagoras",
    "Andreas",
    "Antigonus",
    "Apollo",
    "Archelaus",
    "Archimedes",
    "Aristarchus",
    "Aristides",
    "Aristophanes",
    "Aristoteles",
    "Aristotle",
    "Aristoxenos",
    "Artemidorus",
    "Asclepius",
    "Atticus",
    "Bacchus",
    "Barnabas",
    "Basilides",
    "Bellerophon",
    "Bion",
    "Calchas",
    "Calix",
    "Callias",
    "Callimachus",
    "Cassander",
    "Cephalus",
    "Chariton",
    "Chrysippos",
    "Cimon",
    "Cleisthenes",
    "Cleitus",
    "Cleon",
    "Cleopas",
    "Cleophanes",
    "Clytemnestra",
    "Corydon",
    "Crispus",
    "Crito",
    "Cyrus",
    "Damasus",
    "Damon",
    "Darius",
    "Demetrius",
    "Democritus",
    "Demosthenes",
    "Diogenes",
    "Dionysius",
    "Diophantos",
    "Elias",
    "Epaminondas",
    "Ephialtes",
    "Epimetheus",
    "Epiphanes",
    "Eratosthenes",
    "Eudoxos",
    "Eugenios",
    "Eumenides",
    "Euphemios",
    "Euphemius",
    "Euripides",
    "Evander",
    "Fabian",
    "Flavius",
    "Galen",
    "Glycon",
    "Gorgias",
    "Gorgon",
    "Gorgythion",
    "Gregor",
    "Hector",
    "Hecuba",
    "Hegesippus",
    "Helenus",
    "Hephaestus",
    "Heraclitus",
    "Herakles",
    "Hermes",
    "Herodotus",
    "Hesiod",
    "Hippocrates",
    "Hippolytos",
    "Hippolytus",
    "Hippomenes",
    "Homer",
    "Iason",
    "Icarus",
    "Iphicles",
    "Iphicrates",
    "Isidoros",
    "Isidorus",
    "Ismenias",
    "Ismenios",
    "Isocrates",
    "Jamblichus",
    "Jason",
    "Jocasta",
    "Jocastas",
    "Jonas",
    "Julian",
    "Julius",
    "Kallias",
    "Kallisthenes",
    "Kallistos",
    "Kallixenos",
    "Kallixtus",
    "Kleon",
    "Kyros",
    "Laertes",
    "Laonikos",
    "Leander",
    "Leonidas",
    "Lycurgus",
    "Lykophron",
    "Lykourgos",
    "Lysander",
    "Lysandros",
    "Lysimachus",
    "Lysistratos",
    "Makarios",
    "Marcus",
    "Megas",
    "Menander",
    "Menedemos",
    "Metrophanes",
    "Miltiades",
    "Myron",
    "Narcissus",
    "Nereus",
    "Nestor",
    "Nicomachus",
    "Nicomedes",
    "Nikandros",
    "Nikolaos",
    "Nikon",
    "Odysseus",
    "Oedipus",
    "Olympiodorus",
    "Olympios",
    "Olympos",
    "Onesimos",
    "Orestes",
    "Origen",
    "Origenes",
    "Orion",
    "Orosius",
    "Pallas",
    "Pandarus",
    "Paris",
    "Parmenides",
    "Pausanias",
    "Pelias",
    "Pelops",
    "Pentheus",
    "Pericles",
    "Perseus",
    "Petros",
    "Phaedo",
    "Phaedrus",
    "Philemon",
    "Philip",
    "Philo",
    "Philocles",
    "Philoctetes",
    "Philostratos",
    "Philostratus",
    "Phocion",
    "Phoenix",
    "Phoibos",
    "Phokas",
    "Phokion",
    "Phrixus",
    "Plato",
    "Plutarch",
    "Polybius",
    "Polycarp",
    "Polyclitus",
    "Polycrates",
    "Polydamas",
    "Polydeukes",
    "Polykarp",
    "Polykrates",
    "Polynices",
    "Polypemon",
    "Pompey",
    "Ptolemy",
    "Pyrrhos",
    "Pyrrhus",
    "Pythagoras",
    "Quintus",
    "Raphael",
    "Sappho",
    "Satyros",
    "Simonides",
    "Socrates",
    "Solon",
    "Sophocles",
    "Soterios",
    "Stesichorus",
    "Strabo",
    "Sulla",
    "Telemachus",
    "Telesphorus",
    "Thaddeus",
    "Thales",
    "Thamyris",
    "Thargelion",
    "Tharypas",
    "Themistocles",
    "Theocritus",
    "Theodore",
    "Theokritos",
    "Theophanes",
    "Theophrastus",
    "Theophylaktos",
    "Theseus",
    "Thucydides",
    "Timon",
    "Ulysses",
    "Urbanus",
    "Xander",
    "Xanthos",
    "Xanthus",
    "Xenocrates",
    "Xenophon",
    "Xerxes",
    "Xiphos",
    "Xouthos",
    "Zeno",
    "Zephyrus",
    "Zethus",
    "Zopyros",
    "Zosimos",
    "Zoticus",
    "Zotikos",
]

surnames = [
    "of Abydos",
    "of Acamas",
    "of Acarnania",
    "of Achaia",
    "of Aegae",
    "of Aegina",
    "of Aenus",
    "of Aeolis",
    "of Aetolia",
    "of Ainos",
    "of Alalcomenae",
    "of Amaseia",
    "of Amathus",
    "of Ambracia",
    "of Amphipolis",
    "of Amphissa",
    "of Anactorium",
    "of Antandrus",
    "of Antioch",
    "of Aphytis",
    "of Apollonia",
    "of Arcadia",
    "of Arethusa",
    "of Argos",
    "of Astypalaia",
    "of Athens",
    "of Atlantis",
    "of Aulis",
    "of Axus",
    "of Bargylia",
    "of Bithynia",
    "of Boeotia",
    "of Bosphorus",
    "of Brea",
    "of Buthrotum",
    "of Byblos",
    "of Canopus",
    "of Caria",
    "of Caryatis",
    "of Cassandrea",
    "of Chaeronea",
    "of Chalcedon",
    "of Chalcis",
    "of Chios",
    "of Cilicia",
    "of Cnidus",
    "of Colophon",
    "of Corcyra",
    "of Corfu",
    "of Corinth",
    "of Cos",
    "of Crete",
    "of Crisa",
    "of Crocus",
    "of Croton",
    "of Cydonia",
    "of Cyme",
    "of Cyrene",
    "of Cyzicus",
    "of Delium",
    "of Delos",
    "of Delphi",
    "of Dion",
    "of Dodona",
    "of Doris",
    "of Elea",
    "of Eleusis",
    "of Elis",
    "of Ephesus",
    "of Ephyra",
    "of Epidamnus",
    "of Epidaurus",
    "of Epirus",
    "of Eretria",
    "of Eryx",
    "of Euboea",
    "of Eumaeus",
    "of Euphemia",
    "of Galatia",
    "of Gela",
    "of Gortyn",
    "of Halicarnassus",
    "of Halimous",
    "of Hamaxitos",
    "of Helike",
    "of Hellas",
    "of Hellespont",
    "of Heraclea",
    "of Heraea",
    "of Heraklion",
    "of Hermione",
    "of Himera",
    "of Hipponium",
    "of Hyampolis",
    "of Hybla",
    "of Ialysos",
    "of Iasos",
    "of Icaria",
    "of Ilium",
    "of Illyria",
    "of Iolcos",
    "of Ionian",
    "of Ithaca",
    "of Kameiros",
    "of Karia",
    "of Karyes",
    "of Karystos",
    "of Knidos",
    "of Knossos",
    "of Korydallos",
    "of Kos",
    "of Krete",
    "of Kydonia",
    "of Laconia",
    "of Lamia",
    "of Lampsacus",
    "of Lapithos",
    "of Larisa",
    "of Larissa",
    "of Lebadeia",
    "of Lemnos",
    "of Lesbos",
    "of Leucadia",
    "of Lindos",
    "of Locri",
    "of Locris",
    "of Lydia",
    "of Magnesia",
    "of Mantineia",
    "of Marathon",
    "of Marathus",
    "of Megara",
    "of Melos",
    "of Mesembria",
    "of Methone",
    "of Miletus",
    "of Mycenae",
    "of Mylasa",
    "of Myndos",
    "of Myrina",
    "of Mytilene",
    "of Myus",
    "of Naxos",
    "of Neapolis",
    "of Nemea",
    "of Nicaea",
    "of Nile",
    "of Oeantheia",
    "of Olbia",
    "of Olympia",
    "of Olympus",
    "of Olynthos",
    "of Olynthus",
    "of Orestis",
    "of Paeonia",
    "of Pagasae",
    "of Palaepaphos",
    "of Pallene",
    "of Panormus",
    "of Paphos",
    "of Parium",
    "of Paros",
    "of Patara",
    "of Patrai",
    "of Patras",
    "of Pella",
    "of Peloponnesus",
    "of Pelorus",
    "of Peonia",
    "of Pergamon",
    "of Phaestus",
    "of Pharsalus",
    "of Pheneus",
    "of Phigaleia",
    "of Phigalia",
    "of Phlius",
    "of Phocis",
    "of Phrygia",
    "of Phthiotis",
    "of Piraeus",
    "of Pisa",
    "of Pityus",
    "of Plotheia",
    "of Pluronia",
    "of Pluronic",
    "of Poteidaea",
    "of Potidaea",
    "of Priene",
    "of Pteleon",
    "of Pteleum",
    "of Pydna",
    "of Pylos",
    "of Rhamnous",
    "of Rhegium",
    "of Rhodes",
    "of Sais",
    "of Samos",
    "of Sardis",
    "of Scione",
    "of Selinus",
    "of Sestos",
    "of Sicyon",
    "of Sikyon",
    "of Sila",
    "of Sinope",
    "of Sithonia",
    "of Sparta",
    "of Sphagia",
    "of Sphettus",
    "of Sphodrias",
    "of Stymphalus",
    "of Sybaris",
    "of Syracuse",
    "of Tegea",
    "of Tenedos",
    "of Teos",
    "of Teuthrania",
    "of Thasos",
    "of Thebes",
    "of Thera",
    "of Therma",
    "of Thermopylae",
    "of Thessaly",
    "of Thrace",
    "of Thronium",
    "of Thryos",
    "of Thyatira",
    "of Tilos",
    "of Tiryns",
    "of Tithorea",
    "of Torone",
    "of Trachis",
    "of Troezen",
    "of Troy",
    "of Tumulus",
    "of Xanthos",
    "of Zakynthos",
    "of Zancle",
    "of Zephyrion",
    "of Zeus Ammon",
    "of Zoster",
]



from random import choice, randint


def generate_female_name(female_prefix, female_suffix, min=1, max=1):
    while True:
        try:
            num_prefix_syllables = randint(min, max)
            num_suffix_syllables = randint(min, max)
            if num_prefix_syllables == 0 and num_suffix_syllables == 0:
                raise ValueError

            if num_prefix_syllables == 1 and num_suffix_syllables == 0:
                name = choice(female_prefix)
                return name.capitalize()

            name = ""
            for _ in range(num_prefix_syllables):
                syllable = choice(female_prefix)
                name += syllable

            for _ in range(num_suffix_syllables):
                syllable = choice(female_suffix)
                name += syllable

            return name.capitalize()
        except ValueError:
            continue


def generate_male_name(male_prefix, male_suffix, min=1, max=1):
    while True:
        try:
            num_prefix_syllables = randint(min, max)
            num_suffix_syllables = randint(min, max)
            if num_prefix_syllables == 0 and num_suffix_syllables == 0:
                raise ValueError

            if num_prefix_syllables == 1 and num_suffix_syllables == 0:
                name = choice(male_prefix)
                return name.capitalize()

            name = ""
            for _ in range(num_prefix_syllables):
                syllable = choice(male_prefix)
                name += syllable

            for _ in range(num_suffix_syllables):
                syllable = choice(male_suffix)
                name += syllable

            return name.capitalize()
        except ValueError:
            continue


def generate_surname(surname_syllables, min=2, max=3):
    num_syllables = randint(min, max)
    synth_surname = ""
    for _ in range(num_syllables):
        syllable = choice(surname_syllables)
        synth_surname += syllable

    return synth_surname.capitalize()


def generate_surname_less(surname_prefix, surname_suffix):
    synth_surname = ""
    syllable_prefix = choice(surname_prefix)
    syllable_suffix = choice(surname_suffix)
    synth_surname += syllable_prefix + syllable_suffix

    return synth_surname.capitalize()


def remove_duplicates(namelist):
    # Remove duplicates
    namelist_ordered = list(set(namelist))

    # Sort alphabetically
    namelist_ordered.sort()

    return namelist_ordered


styles = [
    'arab',
    'aztec',
    'chinese',
    'dwarven',
    'elven',
    'english',
    'giant',
    'halfling',
    'japanese',
    'mongolian',
    'norsemen',
    'orc',
    'slavic',
    'greek',
    'steampunk',
    'tolkien',
    'viking',
    'germanic',
    'turkish',
    'human',
    'martin',
    'jordan',
    'erikson',
    'roman',
    'rowling',
    'sapkowski'
    ]



female_prefix = [
    "ai",
    "an",
    "bo",
    "chi",
    "da",
    "en",
    "fu",
    "go",
    "ha",
    "hi",
    "i",
    "ka",
    "ko",
    "mi",
    "na",
    "no",
    "ra",
    "ri",
    "sa",
    "shi",
    "ta",
    "to",
    "tsu",
    "u",
    "ya",
    "yo",
    "zu",
]

female_suffix = [
    "a",
    "aki",
    "ami",
    "aya",
    "chi",
    "e",
    "emi",
    "hana",
    "i",
    "iko",
    "ka",
    "kami",
    "ko",
    "mi",
    "miko",
    "na",
    "nami",
    "no",
    "omi",
    "ra",
    "ri",
    "saki",
    "shi",
    "ta",
    "to",
    "tsuki",
    "u",
    "ya",
    "yo",
]

male_prefix = [
    "ai",
    "ben",
    "chan",
    "da",
    "en",
    "fu",
    "gen",
    "hai",
    "ich",
    "ji",
    "ken",
    "li",
    "ming",
    "nao",
    "ori",
    "po",
    "qing",
    "ren",
    "shen",
    "tai",
    "ui",
    "vui",
    "wen",
    "xi",
    "ya",
    "zen",
]

male_suffix = [
    "bo",
    "chi",
    "do",
    "en",
    "fu",
    "gi",
    "hiro",
    "i",
    "ji",
    "ko",
    "lei",
    "ming",
    "no",
    "ou",
    "po",
    "quan",
    "rong",
    "shi",
    "to",
    "ui",
    "vui",
    "wen",
    "xi",
    "yo",
    "zen",
]

surname_prefix = [
    "chin",
    "da",
    "fu",
    "guan",
    "han",
    "jing",
    "li",
    "mei",
    "ning",
    "qian",
    "rong",
    "shen",
    "ting",
    "wan",
    "xi",
    "yan",
    "zhi",
]

surname_suffix = [
    "bai",
    "chun",
    "feng",
    "hua",
    "ji",
    "lan",
    "mei",
    "nan",
    "ping",
    "qi",
    "rong",
    "shu",
    "ting",
    "wen",
    "xi",
    "yan",
    "ying",
    "zhi",
]

female_names = [
    "Akane",
    "Aki",
    "Akiko",
    "Amaya",
    "Anzu",
    "Aoi",
    "Asuka",
    "Ayame",
    "Chie",
    "Chika",
    "Chisato",
    "Chiyo",
    "Eiko",
    "Emi",
    "Eri",
    "Fujiko",
    "Fumiko",
    "Hana",
    "Hanako",
    "Haru",
    "Haruko",
    "Harumi",
    "Hikari",
    "Hina",
    "Hinata",
    "Hiroko",
    "Hisako",
    "Hitomi",
    "Honoka",
    "Hotaru",
    "Ikue",
    "Ikuko",
    "Inari",
    "Izumi",
    "Kaede",
    "Kaho",
    "Kameko",
    "Kasumi",
    "Katsuko",
    "Kazuko",
    "Kiku",
    "Kimiko",
    "Kiyo",
    "Kiyoko",
    "Kumiko",
    "Kyoko",
    "Mai",
    "Maki",
    "Mami",
    "Mana",
    "Mao",
    "Mari",
    "Mariko",
    "Masako",
    "Mayu",
    "Mayumi",
    "Megumi",
    "Michiko",
    "Midori",
    "Mieko",
    "Mika",
    "Miki",
    "Miku",
    "Minako",
    "Minori",
    "Misaki",
    "Misako",
    "Mitsuko",
    "Miyako",
    "Miyu",
    "Miyuki",
    "Momoko",
    "Mutsuko",
    "Nami",
    "Namiko",
    "Naoko",
    "Natsuko",
    "Natsumi",
    "Nobuko",
    "Nori",
    "Noriko",
    "Rei",
    "Reiko",
    "Rie",
    "Riko",
    "Rina",
    "Risa",
    "Ryoko",
    "Sachiko",
    "Saki",
    "Sakura",
    "Satoko",
    "Sayuri",
    "Setsuko",
    "Shinobu",
    "Shiori",
    "Shizuka",
    "Sumiko",
    "Takako",
    "Takara",
    "Takiko",
    "Tamiko",
    "Toshiko",
    "Umeko",
    "Wakana",
    "Yasuko",
    "Yayoi",
    "Yoko",
    "Yoshie",
    "Yoshiko",
    "Yui",
    "Yuka",
    "Yukari",
    "Yuki",
    "Yukiko",
    "Yumi",
    "Yumiko",
    "Yuriko",
    "Yuu",
    "Yuuko",
    "Yuuna",
    "Yuzu",
    "Yuzuki",
    "Yuzuko",
]

male_names = [
    "Akihiko",
    "Akihiro",
    "Akihito",
    "Akio",
    "Akira",
    "Arata",
    "Atsushi",
    "Chikao",
    "Daichi",
    "Daisuke",
    "Eiji",
    "Fujio",
    "Fumio",
    "Goro",
    "Hachiro",
    "Hajime",
    "Haru",
    "Haruki",
    "Haruto",
    "Hideaki",
    "Hideo",
    "Hideyoshi",
    "Hikaru",
    "Hiroaki",
    "Hiroki",
    "Hiroshi",
    "Hisashi",
    "Hitoshi",
    "Ichiro",
    "Isamu",
    "Itaru",
    "Jiro",
    "Jun",
    "Junichi",
    "Katsuo",
    "Katsuro",
    "Kazuhiko",
    "Kazuhiro",
    "Kazuki",
    "Kazuo",
    "Kei",
    "Keiji",
    "Keisuke",
    "Ken",
    "Kenichi",
    "Kenshin",
    "Kenta",
    "Kiyoshi",
    "Koichi",
    "Koji",
    "Kosuke",
    "Makoto",
    "Mamoru",
    "Masahiro",
    "Masaki",
    "Masanori",
    "Masao",
    "Masashi",
    "Masato",
    "Michio",
    "Minoru",
    "Mitsuo",
    "Naoki",
    "Naoto",
    "Noboru",
    "Nobu",
    "Nobuyuki",
    "Norio",
    "Osamu",
    "Ryo",
    "Ryota",
    "Ryozo",
    "Saburo",
    "Satoshi",
    "Seiji",
    "Shigeo",
    "Shin",
    "Shingo",
    "Shinichi",
    "Shinji",
    "Shinsuke",
    "Shiro",
    "Sho",
    "Shohei",
    "Shota",
    "Shuichi",
    "Shun",
    "Susumu",
    "Tadao",
    "Tadashi",
    "Takao",
    "Takashi",
    "Takehiko",
    "Takeshi",
    "Takumi",
    "Takuya",
    "Taro",
    "Tatsuo",
    "Tatsuya",
    "Tetsuo",
    "Tetsuya",
    "Tomio",
    "Tomohiro",
    "Tomohisa",
    "Tomoki",
    "Tomonori",
    "Toru",
    "Toshiaki",
    "Toshihiro",
    "Toshio",
    "Toshiro",
    "Toshiyuki",
    "Tsuyoshi",
    "Wataru",
    "Yasuo",
    "Yasushi",
    "Yasuyuki",
    "Yoichi",
    "Yoshiaki",
    "Yoshikazu",
    "Yoshinori",
    "Yoshio",
    "Yoshiro",
    "Yosuke",
    "Yota",
    "Yuji",
    "Yuki",
    "Yukio",
    "Yusuke",
    "Yutaka",
    "Yuya",
    "Zenjiro",
]

surnames = [
    "Abe",
    "Akaike",
    "Amaya",
    "Aoki",
    "Asakawa",
    "Chiba",
    "Daigo",
    "Ebina",
    "Enoki",
    "Fujii",
    "Fukuda",
    "Goto",
    "Hamasaki",
    "Haneda",
    "Hara",
    "Harada",
    "Hashimoto",
    "Hattori",
    "Hayashi",
    "Higashi",
    "Hirano",
    "Hirose",
    "Hosokawa",
    "Igarashi",
    "Iida",
    "Ikegami",
    "Inoue",
    "Ishida",
    "Ishikawa",
    "Ishiyama",
    "Itami",
    "Iwai",
    "Iwamoto",
    "Iwasaki",
    "Kagawa",
    "Kajiwara",
    "Kaneko",
    "Kato",
    "Kawaguchi",
    "Kawamoto",
    "Kishimoto",
    "Kobayashi",
    "Koga",
    "Kojima",
    "Komatsu",
    "Kondo",
    "Kubota",
    "Kudo",
    "Kuroda",
    "Maeda",
    "Matsuda",
    "Matsui",
    "Matsuo",
    "Matsushita",
    "Mizuno",
    "Morikawa",
    "Morioka",
    "Moriyama",
    "Nagai",
    "Nagano",
    "Nagata",
    "Nakagawa",
    "Nakajima",
    "Nakamura",
    "Nakanishi",
    "Nakano",
    "Nakayama",
    "Nishida",
    "Nishimura",
    "Nishio",
    "Nishiyama",
    "Ogawa",
    "Ohashi",
    "Oishi",
    "Okamoto",
    "Okamura",
    "Okubo",
    "Ota",
    "Saito",
    "Sakaguchi",
    "Sakamoto",
    "Sasaki",
    "Sato",
    "Sawai",
    "Sawamura",
    "Shibata",
    "Shimada",
    "Shimizu",
    "Shimomura",
    "Shinohara",
    "Shiota",
    "Sugawara",
    "Sugiyama",
    "Suzuki",
    "Takahashi",
    "Takai",
    "Takamoto",
    "Takanashi",
    "Takano",
    "Takeda",
    "Takei",
    "Tamura",
    "Tanaka",
    "Tokunaga",
    "Tomita",
    "Tsuchiya",
    "Tsujimoto",
    "Tsujita",
    "Uchida",
    "Ueda",
    "Uesugi",
    "Umeda",
    "Wada",
    "Watanabe",
    "Yamada",
    "Yamaguchi",
    "Yamamoto",
    "Yamashita",
    "Yamazaki",
    "Yano",
    "Yokoyama",
    "Yoneda",
    "Yoshida",
    "Yoshikawa",
    "Yoshimoto",
    "Yoshizawa",
]



female_suffix = [
    "a",
    "bel",
    "cia",
    "da",
    "el",
    "fae",
    "gwyn",
    "hia",
    "i",
    "ja",
    "ka",
    "la",
    "ma",
    "na",
    "ora",
    "pa",
    "qua",
    "ra",
    "sa",
    "ta",
    "ula",
    "va",
    "wa",
    "xa",
    "ya",
    "za",
    "belle",
    "cey",
    "dine",
    "elle",
    "finn",
    "grace",
    "hira",
    "ira",
    "jade",
    "kara",
    "lynn",
    "mara",
    "nora",
    "opal",
    "phina",
    "quella",
    "rina",
    "sera",
    "tia",
    "una",
    "vella",
    "wren",
    "xina",
    "yara",
    "zara",
]

male_prefix = [
    "ach",
    "an",
    "ar",
    "bal",
    "be",
    "bel",
    "bran",
    "cal",
    "cor",
    "dar",
    "de",
    "del",
    "dra",
    "er",
    "fis",
    "gal",
    "gar",
    "ha",
    "he",
    "hir",
    "il",
    "ja",
    "kel",
    "kor",
    "lar",
    "le",
    "li",
    "ma",
    "mar",
    "na",
    "nor",
    "ol",
    "on",
    "pa",
    "pel",
    "per",
    "qua",
    "ra",
    "ran",
    "rel",
    "ro",
    "sa",
    "sar",
    "sel",
    "tar",
    "te",
    "ti",
    "to",
    "ur",
    "va",
    "var",
    "vel",
    "ver",
    "wa",
    "wal",
    "ya",
    "yar",
    "zel",
]

male_suffix = [
    "ad",
    "al",
    "an",
    "ar",
    "as",
    "av",
    "don",
    "dor",
    "el",
    "en",
    "er",
    "es",
    "gan",
    "har",
    "hor",
    "ian",
    "ic",
    "id",
    "il",
    "in",
    "is",
    "kan",
    "kar",
    "kas",
    "lak",
    "las",
    "lin",
    "lon",
    "mar",
    "mon",
    "nan",
    "nar",
    "nas",
    "non",
    "or",
    "rad",
    "ran",
    "ras",
    "rik",
    "ron",
    "sal",
    "san",
    "tas",
    "tar",
    "tin",
    "ton",
    "ur",
    "us",
    "van",
    "var",
    "ver",
    "von",
    "war",
    "won",
    "yas",
    "zan",
    "zen",
    "zon",
]

female_prefix = [
    "acht",
    "bry",
    "cali",
    "dara",
    "ell",
    "fay",
    "gwen",
    "hela",
    "is",
    "jen",
    "kala",
    "lara",
    "morga",
    "nala",
    "orla",
    "pae",
    "quen",
    "rae",
    "sab",
    "tara",
    "ulan",
    "vay",
    "wyn",
    "xan",
    "yara",
    "zara",
    "bel",
    "cara",
    "dela",
    "ella",
    "fin",
    "grace",
    "hira",
    "ira",
    "jenna",
    "kira",
    "luna",
    "maia",
    "nira",
    "opal",
    "pippa",
    "quela",
    "rona",
    "saffron",
    "tessa",
    "ula",
    "vanna",
    "willa",
    "xara",
    "yuna",
    "zella",
]

surname_syllables = [
    "al",
    "an",
    "ar",
    "ark",
    "as",
    "ash",
    "ba",
    "bar",
    "be",
    "bel",
    "car",
    "cas",
    "cor",
    "da",
    "dal",
    "dar",
    "de",
    "del",
    "di",
    "don",
    "dor",
    "el",
    "en",
    "er",
    "es",
    "fal",
    "far",
    "fi",
    "gal",
    "gar",
    "har",
    "ho",
    "ian",
    "ik",
    "il",
    "in",
    "is",
    "ja",
    "jar",
    "kal",
    "kar",
    "kas",
    "ken",
    "kor",
    "lar",
    "li",
    "lon",
    "ma",
    "mal",
    "mar",
    "mas",
    "mon",
    "na",
    "nal",
    "nar",
    "ni",
    "no",
    "on",
    "or",
    "pa",
    "par",
    "per",
    "qu",
    "ra",
    "ral",
    "ran",
    "ri",
    "ril",
    "ro",
    "ron",
    "sa",
    "sal",
    "sha",
    "si",
    "st",
    "ta",
    "tar",
    "th",
    "thal",
    "thar",
    "thon",
    "ti",
    "tin",
    "tor",
    "un",
    "ur",
    "va",
    "val",
    "var",
    "ver",
    "von",
    "wan",
    "war",
    "wen",
    "win",
    "ya",
    "yar",
    "yen",
    "yin",
    "yor",
    "za",
    "zan",
    "zar",
]

female_names = [
    "Abigail",
    "Ada",
    "Adelaide",
    "Adriana",
    "Alessandra",
    "Alexandra",
    "Alexandria",
    "Amara",
    "Anastasia",
    "Arabella",
    "Aria",
    "Ava",
    "Beatrice",
    "Belle",
    "Bianca",
    "Brianna",
    "Briar",
    "Brielle",
    "Bronwyn",
    "Brynn",
    "Calista",
    "Calliope",
    "Camilla",
    "Cara",
    "Cassandra",
    "Cassiopeia",
    "Charlotte",
    "Clara",
    "Cleo",
    "Dahlia",
    "Daisy",
    "Dana",
    "Daphne",
    "Dara",
    "Delia",
    "Delilah",
    "Della",
    "Delphine",
    "Demetria",
    "Desdemona",
    "Diana",
    "Eden",
    "Eleanor",
    "Elena",
    "Elisabeth",
    "Elle",
    "Eloise",
    "Esmeralda",
    "Eva",
    "Evangeline",
    "Evelyn",
    "Faye",
    "Felicity",
    "Fiona",
    "Fiora",
    "Fleur",
    "Flora",
    "Freya",
    "Gabriella",
    "Gemma",
    "Genevieve",
    "Georgina",
    "Giselle",
    "Grace",
    "Guinevere",
    "Gwen",
    "Gwendolyn",
    "Halle",
    "Hannah",
    "Harper",
    "Hazel",
    "Helena",
    "Hermione",
    "Holly",
    "Imogen",
    "Iris",
    "Isabella",
    "Isabelle",
    "Isadora",
    "Isla",
    "Isolde",
    "Ivy",
    "Jade",
    "Jessamine",
    "Jocelyn",
    "Josephine",
    "Julia",
    "Juliana",
    "Juliette",
    "June",
    "Juno",
    "Kalliope",
    "Kassandra",
    "Katarina",
    "Kate",
    "Katerina",
    "Katherine",
    "Kathleen",
    "Keira",
    "Kiera",
    "Kira",
    "Lara",
    "Lavinia",
    "Leilani",
    "Lena",
    "Lila",
    "Liliana",
    "Lily",
    "Lorelei",
    "Luna",
    "Lyra",
    "Madeline",
    "Maeve",
    "Magdalena",
    "Margot",
    "Matilda",
    "Melisande",
    "Melissa",
    "Mila",
    "Mira",
    "Miranda",
    "Morgana",
    "Nadia",
    "Natalia",
    "Natalie",
    "Nerissa",
    "Nia",
    "Nicolette",
    "Nina",
    "Nora",
    "Octavia",
    "Odessa",
    "Odette",
    "Olive",
    "Olivia",
    "Olympia",
    "Ophelia",
    "Paige",
    "Penelope",
    "Persephone",
    "Piper",
    "Poppy",
    "Primrose",
    "Priscilla",
    "Queenie",
    "Quiana",
    "Quincy",
    "Quinn",
    "Quinta",
    "Quintessa",
    "Rae",
    "Ravenna",
    "Rhiannon",
    "Rosalie",
    "Rosalind",
    "Rose",
    "Rowena",
    "Roxanne",
    "Ruby",
    "Sabrina",
    "Sage",
    "Seraphina",
    "Serena",
    "Skye",
    "Sophia",
    "Stella",
    "Talia",
    "Tallulah",
    "Tatiana",
    "Tess",
    "Tessa",
    "Thalia",
    "Thea",
    "Theodora",
    "Theresa",
    "Ursula",
    "Valentina",
    "Valeria",
    "Vera",
    "Veronica",
    "Vespera",
    "Victoria",
    "Violet",
    "Vivian",
    "Vivienne",
    "Wilhelmina",
    "Willa",
    "Willow",
    "Winifred",
    "Winona",
    "Wren",
    "Xanthe",
    "Xanthia",
    "Xena",
    "Xenia",
    "Xiomara",
    "Yara",
    "Yasmin",
    "Yasmine",
    "Yvaine",
    "Yvette",
    "Yvonne",
    "Zara",
    "Zephyra",
    "Zephyrine",
    "Zinnia",
    "Zoe",
]

male_names = [
    "Aek",
    "Aldan",
    "Aman",
    "Anomander",
    "Anton",
    "Apt",
    "Aran",
    "Ard",
    "Arvid",
    "Asik",
    "Astol",
    "Bak",
    "Bard",
    "Bardin",
    "Baruk",
    "Bellurdan",
    "Ben",
    "Bluerose",
    "Braven",
    "Bryce",
    "Bugg",
    "Cal",
    "Cam",
    "Challice",
    "Cob",
    "Cord",
    "Cot",
    "Cotillion",
    "Cowl",
    "Crok",
    "Crone",
    "Cropp",
    "Crump",
    "Cul",
    "Dace",
    "Dalon",
    "Dancer",
    "Darujhistan",
    "Das",
    "Dassem",
    "Derudan",
    "Detoran",
    "Dismal",
    "Dodge",
    "Duiker",
    "Dunsparrow",
    "Durav",
    "Dwite",
    "Ebbin",
    "Edgewalker",
    "Edur",
    "Ell",
    "Emancipor",
    "Enas",
    "Envy",
    "Erikson",
    "Esbek",
    "Faint",
    "Faradan",
    "Farloe",
    "Feather",
    "Fell",
    "Fiddler",
    "Fingers",
    "Fool",
    "Ganoes",
    "Gedderone",
    "Gentleman",
    "Gesler",
    "Gethol",
    "Giggle",
    "Gleam",
    "Gothos",
    "Grim",
    "Grub",
    "Gruntle",
    "Gryllen",
    "Gurl",
    "Hairlock",
    "Halfpeck",
    "Halt",
    "Harllo",
    "Harth",
    "Heboric",
    "Hedge",
    "Helian",
    "Helm",
    "Hentos",
    "Hess",
    "Hew",
    "Hood",
    "Hope",
    "Hull",
    "Hum",
    "Hunch",
    "Hunthult",
    "Icarium",
    "Imp",
    "Ironbars",
    "Iskar",
    "Itkovian",
    "Jal",
    "Jan",
    "Jardir",
    "Jhenna",
    "Jib",
    "Kal",
    "Kalam",
    "Karsa",
    "Kedeviss",
    "Keneb",
    "Kilmandaros",
    "Kiska",
    "Korbolo",
    "Kruppe",
    "Kurzin",
    "Lar",
    "Laseen",
    "Lawn",
    "Leaf",
    "Leoman",
    "Limp",
    "Little",
    "Lobe",
    "Lorn",
    "Lostara",
    "Lutes",
    "Mallet",
    "Mapo",
    "Mappo",
    "Maral",
    "Marill",
    "Masan",
    "Maw",
    "Mist",
    "Mogora",
    "Mok",
    "Molander",
    "Moon",
    "Morn",
    "Mottle",
    "Mouse",
    "Mule",
    "Munug",
    "Murr",
    "Nefarias",
    "Nether",
    "Nil",
    "Nimander",
    "Nok",
    "Noon",
    "Noto",
    "Obo",
    "Oponn",
    "Orbyn",
    "Ord",
    "Ormulogun",
    "Paralt",
    "Paran",
    "Pate",
    "Pearl",
    "Pella",
    "Pest",
    "Picker",
    "Pilip",
    "Pithy",
    "Pores",
    "Pormqual",
    "Pran",
    "Quick",
    "Raest",
    "Rain",
    "Rake",
    "Rallick",
    "Ramp",
    "Rat",
    "Rath",
    "Raven",
    "Redmask",
    "Rhulad",
    "Rissarh",
    "Roach",
    "Rotch",
    "Ryllandaras",
    "Samar",
    "Sandalath",
    "Sands",
    "Sawark",
    "Scar",
    "Scillara",
    "Scorch",
    "Senu",
    "Sever",
    "Shadowthrone",
    "Shake",
    "Shaky",
    "Shardan",
    "Shaven",
    "Shimmer",
    "Siballe",
    "Sight",
    "Sil",
    "Silchas",
    "Skintick",
    "Skorgen",
    "Skovald",
    "Skullcup",
    "Skulldeath",
    "Sleek",
    "Slink",
    "Smack",
    "Smiles",
    "Snell",
    "Spindle",
    "Squint",
    "Stalker",
    "Stavi",
    "Steep",
    "Stork",
    "Stormy",
    "Stryke",
    "Studlock",
    "Sudden",
    "Sump",
    "Sword",
    "Talamandas",
    "Tanas",
    "Tanno",
    "Tattersail",
    "Tayschrenn",
    "Teal",
    "Tehol",
    "Temper",
    "Temul",
    "Tene",
    "Thelomen",
    "Throatslitter",
    "Tick",
    "Toc",
    "Togg",
    "Tool",
    "Torvald",
    "Trail",
    "Trake",
    "Tree",
    "Trotts",
    "Trull",
    "Tulas",
    "Tulip",
    "Turban",
    "Turlow",
    "Twilight",
    "Twist",
    "Ublala",
    "Udinaas",
    "Ullen",
    "Urb",
    "Urko",
    "Ursto",
    "Uru",
    "Valan",
    "Vandal",
    "Vastly",
    "Ved",
    "Vedith",
    "Venitt",
    "Verdith",
    "Vigor",
    "Vorcan",
    "Wahr",
    "Wan",
    "Wander",
    "Wane",
    "Wave",
    "Weasel",
    "Whiskeyjack",
    "Wickan",
    "Widdershins",
    "Willis",
    "Wish",
    "Woke",
    "Woolie",
    "Worry",
    "Yan",
    "Yath",
    "Yedan",
    "Yghatan",
    "Yil",
    "Yusek",
    "Yuupe",
    "Zar",
    "Zaravow",
    "Zed",
    "Zelman",
    "Zephyr",
    "Zeth",
    "Zol",
    "Zolan",
]

surnames = [
    "Albel",
    "Ancorril",
    "Anroyin",
    "Aril",
    "Arkanhar",
    "Arkas",
    "Arkashran",
    "Arkyarth",
    "Armar",
    "Artorbar",
    "Ashil",
    "Ashlon",
    "Ashsa",
    "Ashsalur",
    "Ashtar",
    "Assithon",
    "Bakarvar",
    "Baonmar",
    "Baperer",
    "Barfal",
    "Barin",
    "Barsal",
    "Bathar",
    "Beashvar",
    "Belalkas",
    "Belaswen",
    "Belzarzar",
    "Betardal",
    "Carjaron",
    "Casel",
    "Caspa",
    "Castitar",
    "Casur",
    "Cornoyin",
    "Daldalel",
    "Darron",
    "Dedi",
    "Deinral",
    "Dekasfal",
    "Delthongal",
    "Dest",
    "Diash",
    "Dibarin",
    "Dijarde",
    "Diti",
    "Dondiral",
    "Dorharwan",
    "Elvervar",
    "Enva",
    "Enyakor",
    "Erbelgar",
    "Eres",
    "Eril",
    "Ersa",
    "Erst",
    "Falni",
    "Falwan",
    "Fiarkdor",
    "Ficas",
    "Galta",
    "Garas",
    "Garst",
    "Harnoark",
    "Hodeles",
    "Ikkal",
    "Iklar",
    "Ikridi",
    "Illarqu",
    "Inkor",
    "Inorzan",
    "Ishar",
    "Islihar",
    "Isran",
    "Isver",
    "Jagal",
    "Jaharya",
    "Jalarcar",
    "Jarnoth",
    "Kaldarral",
    "Kaldeno",
    "Kaldoncar",
    "Kalgarjar",
    "Kallon",
    "Kardonark",
    "Karfaril",
    "Karik",
    "Kasvalash",
    "Kenlar",
    "Kenparil",
    "Kornalbar",
    "Korurmar",
    "Laralik",
    "Larbe",
    "Larin",
    "Larmon",
    "Londitor",
    "Lonfar",
    "Mafi",
    "Maldalkor",
    "Malkor",
    "Malsa",
    "Mares",
    "Marthon",
    "Masas",
    "Masst",
    "Mathalsha",
    "Mondethon",
    "Nabequ",
    "Nafal",
    "Naldorva",
    "Nalfal",
    "Naljawin",
    "Narashde",
    "Nargarsal",
    "Nielwan",
    "Nikorark",
    "Nimapar",
    "Nodar",
    "Nojar",
    "Nowar",
    "Onianin",
    "Onper",
    "Orunhar",
    "Pawan",
    "Pawen",
    "Racaris",
    "Rador",
    "Raeras",
    "Rafarper",
    "Ralran",
    "Ralvonken",
    "Ranashtar",
    "Ranfi",
    "Ranilper",
    "Ranva",
    "Ranvon",
    "Raralri",
    "Rawar",
    "Rima",
    "Romal",
    "Roner",
    "Rowarsal",
    "Sacaslar",
    "Salon",
    "Saltin",
    "Sayen",
    "Sili",
    "Sitin",
    "Stash",
    "Stilda",
    "Stnar",
    "Stshade",
    "Stsi",
    "Stsiun",
    "Tapar",
    "Tardonun",
    "Thalbaron",
    "Thaliktin",
    "Thalronlar",
    "Tharcartor",
    "Thbe",
    "Thmarel",
    "Thsi",
    "Thwin",
    "Tiunkal",
    "Torkal",
    "Torva",
    "Untor",
    "Urarkthal",
    "Urdelqu",
    "Urgal",
    "Urver",
    "Vahargal",
    "Vallon",
    "Valon",
    "Valva",
    "Vazanbe",
    "Veren",
    "Verisde",
    "Verken",
    "Vertival",
    "Vonel",
    "Wankason",
    "Wanmarmal",
    "Waron",
    "Wenkasth",
    "Wenta",
    "Winhofal",
    "Yarlar",
    "Yarlaris",
    "Yaurlon",
    "Yenmartor",
    "Yenri",
    "Yentharis",
    "Yenzan",
    "Yorbelsa",
    "Zadonthal",
    "Zanal",
    "Zapaash",
]



female_prefix = [
    "ac",
    "atl",
    "ca",
    "ce",
    "ci",
    "co",
    "cu",
    "ehe",
    "eya",
    "hua",
    "ihi",
    "iht",
    "ix",
    "nan",
    "net",
    "nix",
    "pa",
    "pan",
    "pap",
    "pat",
    "pix",
    "que",
    "qui",
    "quim",
    "quit",
    "te",
    "tel",
    "tet",
    "tla",
    "tlah",
    "tle",
    "tli",
    "tlil",
    "tlip",
    "tlot",
    "to",
    "toc",
    "ton",
    "toz",
    "ya",
    "yac",
    "yan",
    "yau",
    "yo",
    "zac",
    "zan",
    "zet",
    "zo",
]

female_suffix = [
    "a",
    "ac",
    "ach",
    "al",
    "amal",
    "atl",
    "ayotl",
    "coyotl",
    "e",
    "eh",
    "etl",
    "huac",
    "icu",
    "ih",
    "il",
    "in",
    "ixtli",
    "iyotl",
    "lauh",
    "liztli",
    "ma",
    "mal",
    "mecatl",
    "mi",
    "nah",
    "nal",
    "ni",
    "niztli",
    "qui",
    "quih",
    "quixtli",
    "tli",
    "tlil",
    "tlixtli",
    "tzin",
    "xi",
    "xih",
    "xihuitl",
    "xoch",
    "yaotl",
    "yoh",
    "yohtl",
    "yol",
    "yolt",
    "ztli",
    "ztoc",
    "zton",
]

male_prefix = [
    "ac",
    "ahu",
    "atl",
    "ca",
    "calli",
    "chi",
    "co",
    "cua",
    "cuauh",
    "ehe",
    "hue",
    "hua",
    "ic",
    "it",
    "itz",
    "iuh",
    "ma",
    "me",
    "miqui",
    "mo",
    "nec",
    "nequi",
    "nel",
    "oco",
    "ohu",
    "op",
    "oy",
    "quauh",
    "quim",
    "tac",
    "tla",
    "tlac",
    "tlal",
    "tlan",
    "tlap",
    "tlat",
    "tlau",
    "tlax",
    "tlil",
    "to",
    "tocht",
    "tol",
    "tona",
    "top",
    "tzi",
    "xi",
    "xim",
    "ya",
    "yac",
    "yauh",
    "yi",
    "yol",
    "yohu",
    "zac",
    "zahui",
    "zal",
    "zitl",
]

male_suffix = [
    "ac",
    "ach",
    "ahual",
    "amatl",
    "ani",
    "atl",
    "auh",
    "calli",
    "catl",
    "chitl",
    "coatl",
    "eh",
    "huey",
    "huic",
    "huitl",
    "ic",
    "itl",
    "iuhtli",
    "mecatl",
    "mi",
    "nacatl",
    "nahual",
    "nahui",
    "nan",
    "nauac",
    "necatl",
    "neh",
    "nochtli",
    "oa",
    "ol",
    "oqu",
    "qui",
    "quiztli",
    "tecatl",
    "temoc",
    "teo",
    "tep",
    "tlahto",
    "tlalli",
    "tlaloc",
    "tlan",
    "tlapal",
    "tlauh",
    "tlaz",
    "tli",
    "tlil",
    "tocatl",
    "ton",
    "topiltz",
    "totl",
    "tzin",
    "xiu",
    "xoc",
    "yahu",
    "yecatl",
    "yohu",
    "zac",
    "zacatl",
    "zalt",
]

surname_prefix = [
    "ac",
    "atl",
    "co",
    "cuauh",
    "eh",
    "huitz",
    "ixt",
    "itz",
    "mec",
    "nahu",
    "ne",
    "o",
    "pah",
    "tla",
    "tecu",
    "tep",
    "tetl",
    "tlac",
    "tlan",
    "tlap",
    "tlat",
    "tlax",
    "tlay",
    "toc",
    "tocht",
    "tzi",
    "ya",
    "yac",
    "yah",
    "yol",
    "zac",
    "zoc",
]

surname_suffix = [
    "an",
    "atl",
    "coatl",
    "ehuac",
    "ic",
    "il",
    "itl",
    "itzin",
    "lini",
    "li",
    "mecatl",
    "motl",
    "nahual",
    "pilli",
    "qui",
    "tli",
    "tlil",
    "tontli",
    "tzi",
    "tzin",
    "tzintli",
    "yaotl",
    "ye",
    "yotl",
    "zon",
]

female_names = [
    "Acatl",
    "Ahuic",
    "Amoxtli",
    "Atlacoya",
    "Ayauhcihuatl",
    "Chalchiuhtlicue",
    "Chicomecoatl",
    "Chimalli",
    "Chimalmatl",
    "Cihuacoatl",
    "Cipactli",
    "Citlali",
    "Coatl",
    "Coyolxauhqui",
    "Cualli",
    "Cuetlaxochitl",
    "Cuixtli",
    "Ehecatl",
    "Eloxochitl",
    "Etl",
    "Huehuecoyotl",
    "Ilhicamina",
    "Itzcoatl",
    "Itzel",
    "Ixchel",
    "Iztac",
    "Iztacihuatl",
    "Iztli",
    "Iztpapalotl",
    "Mazatl",
    "Mictlancihuatl",
    "Mictlantecuhtli",
    "Miquiztli",
    "Nahuatl",
    "Namacuix",
    "Necahual",
    "Nenetl",
    "Nochtli",
    "Ollin",
    "Opochtli",
    "Patecatl",
    "Piltzintli",
    "Quauhtli",
    "Quetzalcoatl",
    "Tecpatl",
    "Teicuih",
    "Tepeyollotl",
    "Tezcacoatl",
    "Tlacaelel",
    "Tlachinolli",
    "Tlaco",
    "Tlahuizcalpantecuhtli",
    "Tlaloc",
    "Tlalocan",
    "Tlalocayotl",
    "Tlalpan",
    "Tlanextli",
    "Tlapalli",
    "Tlatlauhqui",
    "Tlatzolli",
    "Tlazolteotl",
    "Tlecuhtli",
    "Tochintli",
    "Tochtepec",
    "Tochtli",
    "Toci",
    "Toltecatl",
    "Tonalli",
    "Tonalnan",
    "Tonalpohualli",
    "Tonalteotl",
    "Tonantzin",
    "Topiltzin",
    "Totochtin",
    "Totoquihuatzin",
    "Tzitzimitl",
    "Xihuitl",
    "Xilonen",
    "Xipe",
    "Xipil",
    "Xipilli",
    "Xiuh",
    "Xiuhcoatl",
    "Xiuhcozatl",
    "Xiuhtecuhtli",
    "Xiuhtlatl",
    "Xochipilli",
    "Xochiquetzal",
    "Xochiqui",
    "Xochitl",
    "Xochitli",
    "Xoco",
    "Xocoatl",
    "Yacotzin",
    "Yacuicatl",
    "Yanamari",
    "Yaocihuatl",
    "Yauhtli",
    "Yayauhqui",
    "Yazpikua",
    "Yohualli",
    "Yohualticitl",
    "Yolcuat",
    "Yollotl",
    "Yolotl",
    "Yolotzin",
    "Yolotzintli",
    "Yolyamanitzin",
    "Yoxallin",
    "Yoxemil",
    "Yoxiuh",
    "Yoxonotli",
    "Yoyontzin",
    "Zacatzin",
    "Zacualpan",
    "Zani",
    "Zaquitl",
    "Zitlalpopoca",
    "Zitlalxochitl",
    "Zitlalzin",
    "Zolin",
    "Zontecomatl",
    "Zoqui",
]

male_names = [
    "Acalan",
    "Acatl",
    "Achiuhtli",
    "Acolnahuacatl",
    "Acolmiztli",
    "Acolmiztle",
    "Ahcalotl",
    "Ahuítzotl",
    "Ahtahkakoop",
    "Ahtziri",
    "Amacui",
    "Ameyal",
    "Amoxtli",
    "Amoxtzin",
    "Atlixcatzin",
    "Atotonilco",
    "Ayacahuite",
    "Ayauhtzin",
    "Cacamatzin",
    "Cacauatzin",
    "Cachi",
    "Camaxtli",
    "Camaxtzin",
    "Canauhtli",
    "Caxcan",
    "Chalchiuhtlatonac",
    "Chalchiuhtlatonatzin",
    "Chalmecatl",
    "Chaltonac",
    "Chantico",
    "Chiauhque",
    "Chicomexochtli",
    "Chimalpopoca",
    "Cihuaton",
    "Cipactli",
    "Cipriano",
    "Citlalatonac",
    "Citlalatonatzin",
    "Coatl",
    "Coatlaxopeuh",
    "Cochitlehua",
    "Cojontli",
    "Copil",
    "Coyolchiuhqui",
    "Cualli",
    "Cuauhtémoc",
    "Cuauhtemōx",
    "Cuauhtémotz",
    "Cuauhtemōtzin",
    "Cuauhtli",
    "Cuautle",
    "Cuetlachtli",
    "Cuitláhuac",
    "Cuitlauac",
    "Cuitlahuac",
    "Cuxirimay",
    "Ehecatl",
    "Eloxochitl",
    "Huehuetoca",
    "Huemac",
    "Huematzin",
    "Huexotzinco",
    "Huitzilihuitl",
    "Huitzitzilin",
    "Huitzilopochtli",
    "Huitznahua",
    "Huixtocihuatl",
    "Hueyapan",
    "Ichtaca",
    "Itzcoatl",
    "Itzli",
    "Itztli",
    "Ixcoatl",
    "Ixtli",
    "Ixtlilcueitl",
    "Ixtlilxochitl",
    "Ixtilton",
    "Ixtolinqui",
    "Macuil",
    "Malinalxochitl",
    "Mazatl",
    "Meztli",
    "Mictlantecuhtli",
    "Mictlancihuatl",
    "Mictlantecutli",
    "Miztli",
    "Moctezuma",
    "Moctezumatzin",
    "Molinan",
    "Nahuitl",
    "Namacuix",
    "Nanahuatzin",
    "Napay",
    "Necalli",
    "Necuametl",
    "Nezahualcóyotl",
    "Nexahualpilli",
    "Nexahualpillia",
    "Nochtli",
    "Noxochicoztli",
    "Noxochitl",
    "Ohtli",
    "Olin",
    "Opochtli",
    "Oquichtli",
    "Otomitl",
    "Papalotl",
    "Patli",
    "Pilam",
    "Piltzintecuhtli",
    "Piltzintli",
    "Popocatépetl",
    "Quauhtli",
    "Quauitl",
    "Quetzalcoatl",
    "Quintilio",
    "Tecpaocelotl",
    "Tecpatl",
    "Tepiltzin",
    "Tepeyollotl",
    "Tequihuah",
    "Teuhtli",
    "Teyacapan",
    "Teyacapanecatl",
    "Tezcacoatl",
    "Tezcatlipoca",
    "Tezozomoc",
    "Tezozomoctli",
    "Tihtlán",
    "Tlahuicole",
    "Tlaloc",
    "Tlalocatl",
    "Tlalocihuatl",
    "Tlalli",
    "Tlaltecatzin",
    "Tlaltecuhtli",
    "Tlamacazqui",
    "Tlamatzincatl",
    "Tlilpotonqui",
    "Tliltzin",
    "Tocatl",
    "Tochtli",
    "Toxcatl",
    "Tutlahui",
    "Tzilacatzin",
    "Tzitzimitl",
    "Tzonpantli",
    "Uemac",
    "Uitzilopochtli",
    "Xicalango",
    "Xihuitl",
    "Xipilli",
    "Xiuhtecuhtli",
    "Xocotl",
    "Xochicuicatl",
    "Xochihuehuetl",
    "Xochipilli",
    "Xochiquetzal",
    "Xoco",
    "Xocomil",
    "Yaotl",
    "Yolihuani",
    "Yolotli",
    "Yolyamanitzin",
    "Zolin",
    "Zolinqui",
    "Zolinzontli",
]

surnames = [
    "(Amber Glow)",
    "(Amber Leaf)",
    "(Amber Twilight)",
    "(Amethyst Sky)",
    "(Ancient Ritual)",
    "(Ancient Stones)",
    "(Aurora's Grace)",
    "(Autumn Leaf)",
    "(Autumn's Breath)",
    "(Blossom Dance)",
    "(Blossom's Embrace)",
    "(Bountiful Harvest)",
    "(Bramble Thorn)",
    "(Celestial Beacon)",
    "(Celestial Dance)",
    "(Celestial Gateway)",
    "(Celestial Harmony)",
    "(Celestial Whispers)",
    "(Crescent Moon)",
    "(Crimson Twilight)",
    "(Dew-kissed Petals)",
    "(Divine Flame)",
    "(Dreamer's Dream)",
    "(Dreamer's Haven)",
    "(Dreamer's Refuge)",
    "(Dreamweaver)",
    "(Druid's Blessing)",
    "(Earth's Child)",
    "(Earthbound Wanderer)",
    "(Echoing Whispers)",
    "(Ember Glow)",
    "(Emerald Glade)",
    "(Emerald Oasis)",
    "(Emerald Whisper)",
    "(Enchanted Arboretum)",
    "(Enchanted Cascade)",
    "(Enchanted Ember)",
    "(Enchanted Forest)",
    "(Enchanted Grove)",
    "(Enchanted Sanctuary)",
    "(Enchanted Thicket)",
    "(Enchanted Waterfall)",
    "(Enigmatic Echo)",
    "(Eternal Bliss)",
    "(Eternal Journey)",
    "(Eternal Solitude)",
    "(Eternal Twilight)",
    "(Ethereal Mist)",
    "(Evergreen Refuge)",
    "(Evergreen Sentinel)",
    "(Everlasting Meadow)",
    "(Fairy's Kiss)",
    "(Fairy's Lullaby)",
    "(Fairy's Whim)",
    "(Fern Whisperer)",
    "(Firefly Glade)",
    "(Frostbitten Path)",
    "(Frostfire Valley)",
    "(Frostwind Vale)",
    "(Frozen Forest)",
    "(Frozen Lake)",
    "(Gentle Rain)",
    "(Golden Harvest)",
    "(Golden Sunset)",
    "(Hallowed Ground)",
    "(Hallowed Sanctuary)",
    "(Harmony Song)",
    "(Harmony's Echo)",
    "(Harmony's Song)",
    "(Harvest Moon)",
    "(Hidden Path)",
    "(Jade Serpent)",
    "(Journey's Beginning)",
    "(Journey's End)",
    "(Lily Pad's Secret)",
    "(Lorekeeper)",
    "(Luminous Echo)",
    "(Luminous Glow)",
    "(Luminous Oasis)",
    "(Lunar Enchantment)",
    "(Majestic Forest)",
    "(Majestic Peaks)",
    "(Meadowlark's Call)",
    "(Mistweaver)",
    "(Moonbeam Glow)",
    "(Moonlit Enchantment)",
    "(Moonlit Meadow)",
    "(Moonlit Oasis)",
    "(Moonlit Reflection)",
    "(Moonlit Serenade)",
    "(Moonstone Path)",
    "(Mossy Glade)",
    "(Mossy Grotto)",
    "(Mossy Hollow)",
    "(Mossy Pathway)",
    "(Mossy Stones)",
    "(Mountain's Majesty)",
    "(Mystic Caverns)",
    "(Mystic Dreamer)",
    "(Mystic Echoes)",
    "(Mystic Journey)",
    "(Mystic Runes)",
    "(Mystic Wanderer)",
    "(Mystical Nomad)",
    "(Nature's Embrace)",
    "(Nightfall Hymn)",
    "(Nightshade Grove)",
    "(Nightshade Moon)",
    "(Nightshade Serenade)",
    "(Nightshade Whisper)",
    "(Oakheart)",
    "(Rainbow Serenade)",
    "(Rainbow's Promise)",
    "(Raindrop Melody)",
    "(Raindrop Serenade)",
    "(Raven's Cry)",
    "(Raven's Feather)",
    "(Raven's Flight)",
    "(Raven's Haven)",
    "(Raven's Wing)",
    "(River Serenade)",
    "(River of Serenity)",
    "(River's Reflection)",
    "(River's Song)",
    "(Rune Carver)",
    "(Sacred Haven)",
    "(Sacred Oak)",
    "(Sacred Spring)",
    "(Sacred Whispers)",
    "(Sage's Haven)",
    "(Sage's Path)",
    "(Sage's Wisdom)",
    "(Sagebrush Tales)",
    "(Secret Grove)",
    "(Secret Whispers)",
    "(Serenity's Call)",
    "(Shimmering Cascade)",
    "(Silent Forest)",
    "(Silent Watcher)",
    "(Silver Mist)",
    "(Solar Eclipse)",
    "(Solar Flare)",
    "(Solar Radiance)",
    "(Solar Serenade)",
    "(Solitary Seeker)",
    "(Song of the River)",
    "(Soul Seeker)",
    "(Soul's Journey)",
    "(Soul's Sanctuary)",
    "(Spirit Seeker)",
    "(Spirit Weaver)",
    "(Spiritual Resonance)",
    "(Stardust Haven)",
    "(Stardust Symphony)",
    "(Starlit Haven)",
    "(Starlit Sky)",
    "(Starry Constellation)",
    "(Starry Nightfall)",
    "(Storm's Fury)",
    "(Stormborn)",
    "(Sun-kissed Valley)",
    "(Sunbeam's Embrace)",
    "(Thistle Thorne)",
    "(Thorned Bramble)",
    "(Thorned Briar)",
    "(Thorned Rose)",
    "(Thorned Vine)",
    "(Thunder's Echo)",
    "(Thunder's Fury)",
    "(Thunderous Roar)",
    "(Thunderstorm)",
    "(Twilight Reflections)",
    "(Twilight Shadows)",
    "(Twilight Veil)",
    "(Twilight Whispers)",
    "(Wandering Breeze)",
    "(Wandering Spirit)",
    "(Wandering Willow)",
    "(Whirling Vortex)",
    "(Whispered Incantation)",
    "(Whispering Brook)",
    "(Whispering Echoes)",
    "(Whispering Embers)",
    "(Whispering Hollow)",
    "(Whispering Willow)",
    "(Whispering Woods)",
    "(Whispering Zephyr)",
    "(Wildflower Fields)",
    "(Wildwood Wanderer)",
    "(Willow Whisper)",
    "(Wisp of Twilight)",
    "(Woodland Guardian)",
    "(Zephyr's Breath)",
    "(Zephyr's Caress)",
    "(Zephyr's Touch)",
]
